@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
 from contrast.agent import scope
@@ -9,19 +9,39 @@ from contrast.agent.assess.policy import source_policy
 from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.assess.utils import get_self_for_method
 from contrast.agent.settings_state import SettingsState
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_safely, log_time
 
 
+def check_or_enter_scope(orig_func):
+    """
+    Decorator that checks if we're in contrast scope. If so, return immediately, else
+    call the original function in contrast scope.
+
+    Sometimes it is essential that the very first action we take when a method is called
+    is a scope check. If we hit any instrumented method before this check, we'll be in
+    an infinite recursion. This decorator must be the topmost (first) if it's used.
+    """
+
+    def wrapper(*args, **kwargs):
+        if scope.in_contrast_scope():
+            return
+        with scope.contrast_scope():
+            orig_func(*args, **kwargs)
+
+    return wrapper
+
+
+@check_or_enter_scope  # NOTE: this decorator must come first!
+@log_time("Entering analyze")
 @fail_safely("Failed to perform assess analysis.")
 def analyze(context, patch_policy, result, args, kwargs):
-    if skip_analysis(context):
+    if not context or not SettingsState().is_assess_enabled():
         return
 
-    with scope.contrast_scope():
-        self_obj = get_self_for_method(patch_policy, args)
-        preshift = Preshift(self_obj, args, kwargs)
+    self_obj = get_self_for_method(patch_policy, args)
+    preshift = Preshift(self_obj, args, kwargs)
 
-        _analyze(patch_policy, preshift, self_obj, result, args, kwargs)
+    _analyze(patch_policy, preshift, self_obj, result, args, kwargs)
 
 
 def skip_analysis(context):
