@@ -1,93 +1,135 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from contrast.extern import wrapt
+
 import contrast
 from contrast.agent import scope
+from contrast.agent.policy import patch_manager
 from contrast.agent.assess.policy.utils import build_method_name, logger
 from contrast.agent.assess.policy.analysis import analyze
-from contrast.extern.wrapt import ObjectProxy
+from contrast.utils.patch_utils import add_watermark
 
 
-def assess_method(original_method, patch_policy, *args, **kwargs):
+def build_assess_method(original_method, patch_policy):
     """
-    Patching method to replace old method and call our assess code with the original method
+    Creates method to replace old method and call our assess code with the original method
+
     :param original_method: method to call for result
     :param patch_policy: PatchLocationPolicy containing all policy nodes for this patch
-    :param args: method args
-    :param kwargs: method kwargs
-    :return: result of original method
+    :return: Newly created patch function
     """
-    context = contrast.CS__CONTEXT_TRACKER.current()
 
-    try:
-        result = original_method(*args, **kwargs)
-    except Exception:
-        result = None
-        raise
-    finally:
-        analyze(context, patch_policy, result, args, kwargs)
+    def assess_method(*args, **kwargs):
+        context = contrast.CS__CONTEXT_TRACKER.current()
 
-    return result
+        try:
+            result = original_method(*args, **kwargs)
+        except Exception:
+            result = None
+            raise
+        finally:
+            analyze(context, patch_policy, result, args, kwargs)
+
+        return result
+
+    return add_watermark(assess_method)
 
 
-def assess_classmethod(original_method, patch_policy, *args, **kwargs):
+def build_assess_method_wrapt(original_method, patch_policy):
     """
-    Patching method to replace old method and call our assess code with the original method
+    identical to build_assess_method, but with a wrapt wrapper
+    """
+
+    @wrapt.function_wrapper
+    def assess_method_wrapper(wrapped, instance, args, kwargs):
+        context = contrast.CS__CONTEXT_TRACKER.current()
+
+        try:
+            result = wrapped(*args, **kwargs)
+        except Exception:
+            result = None
+            raise
+        finally:
+            analyze(context, patch_policy, result, args, kwargs)
+
+        return result
+
+    return add_watermark(assess_method_wrapper(original_method))
+
+
+def build_assess_classmethod(original_method, patch_policy):
+    """
+    Creates method to replace old method and call our assess code with the original method
+
     :param original_method: method to call for result
     :param patch_policy: PatchLocationPolicy containing all policy nodes for this patch
-    :param args: method args
-    :param kwargs: method kwargs
-    :return: result of original method
+    :return: Newly created patch function
 
     A separate method was required for classmethod patch because we need to remove
     argument 1. arg 1 is the class. This is something that is automatically passed to
     the function so passing it again will cause a TypeError.
     """
-    context = contrast.CS__CONTEXT_TRACKER.current()
+    original_method = patch_manager.as_func(original_method)
 
-    try:
-        result = original_method(*args[1:], **kwargs)
-    except Exception:
-        result = None
-        raise
-    finally:
-        analyze(context, patch_policy, result, args, kwargs)
+    def assess_classmethod(*args, **kwargs):
+        context = contrast.CS__CONTEXT_TRACKER.current()
 
-    return result
+        try:
+            result = original_method(*args, **kwargs)
+        except Exception:
+            result = None
+            raise
+        finally:
+            analyze(context, patch_policy, result, args, kwargs)
+
+        return result
+
+    return add_watermark(assess_classmethod)
 
 
-def assess_deadzone(original_method, patch_policy, *args, **kwargs):
+def build_assess_deadzone(original_method, patch_policy):
     """
-    Patching method to replace old method and call the old method in contrast scope,
-    preventing any analysis down the stack.
+    Creates patch method that calls original method in contrast scope
+
+    This prevents any analysis down the stack.
 
     :param original_method: method to call for result
     :param patch_policy: PatchLocationPolicy containing all policy nodes for this patch
-    :param args: method args
-    :param kwargs: method kwargs
-    :return: result of original method
+    :return: Newly created patch function
     """
-    with scope.contrast_scope():
-        return original_method(*args, **kwargs)
+
+    def assess_deadzone(*args, **kwargs):
+        with scope.contrast_scope():
+            return original_method(*args, **kwargs)
+
+    return add_watermark(assess_deadzone)
 
 
-def assess_property(original_property_name, patch_policy, *args, **kwargs):
+def build_assess_property_fget(original_property_name, patch_policy):
     """
-    Calls the original property by looking for it in in the cs_assess_{property} location
-    to return the property value, and run assess analysis.
-    """
-    context = contrast.CS__CONTEXT_TRACKER.current()
-    try:
-        cls_instance = args[0]
-        cs_method_name = build_method_name(original_property_name)
-        result = getattr(cls_instance, cs_method_name)
-    except Exception:
-        result = None
-        raise
-    finally:
-        analyze(context, patch_policy, result, args, kwargs)
+    Creates property getter to replace old property and call assess code for analysis
 
-    return result
+    The new property calls the original property by looking for it in in the
+    cs_assess_{property} location to return the property value, and run assess
+    analysis.
+    """
+    cs_method_name = build_method_name(original_property_name)
+
+    def assess_property(*args, **kwargs):
+        context = contrast.CS__CONTEXT_TRACKER.current()
+        try:
+            cls_instance = args[0]
+            result = getattr(cls_instance, cs_method_name)
+        except Exception:
+            result = None
+            raise
+        finally:
+            analyze(context, patch_policy, result, args, kwargs)
+
+        return result
+
+    return add_watermark(assess_property)
 
 
 def apply_cached_property(cls_or_module, patch_policy, property_name, orig_property):
@@ -108,7 +150,7 @@ def apply_cached_property(cls_or_module, patch_policy, property_name, orig_prope
     return True
 
 
-class CachedPropertyProxy(ObjectProxy):
+class CachedPropertyProxy(wrapt.ObjectProxy):
     cs__attr_name = None
     cs__patch_policy = None
 
