@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.six import integer_types
 
@@ -139,9 +139,9 @@ class PropagationNode(PolicyNode):
 
         return sources
 
-    @staticmethod
-    def from_dict(obj):
-        return PropagationNode(
+    @classmethod
+    def from_dict(cls, obj):
+        return cls(
             obj[constants.JSON_MODULE],
             obj.get(constants.JSON_CLASS_NAME, ""),
             obj.get(constants.JSON_INSTANCE_METHOD, True),
