@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from . import stream_propagator
 from .base_propagator import BasePropagator, SUPPORTED_TYPES
 from .append_propagator import AppendPropagator
 from .center_propagator import CenterPropagator
+from .codecs_splat_propagator import CodecsSplatPropagator
 from .format_propagator import FormatPropagator
 from .join_propagator import JoinPropagator
 from .json_propagator import JsonPropagator
@@ -12,6 +13,7 @@ from .keep_propagator import KeepPropagator
 from .prepend_propagator import PrependPropagator
 from .replace_propagator import ReplacePropagator
 from .safe_join_propagator import SafeJoinPropagator
+from .safe_join_propagator_django import SafeJoinDjangoPropagator
 from .slice_propagator import SlicePropagator
 from .splat_propagator import SplatPropagator
 from .split_propagator import SplitPropagator
@@ -24,6 +26,7 @@ from .repr_propagator import ReprPropagator
 
 APPEND_ACTION = "APPEND"
 CENTER_ACTION = "CENTER"
+CODECS_SPLAT_ACTION = "CODECS_SPLAT"
 FORMAT_ACTION = "FORMAT"
 JOIN_ACTION = "JOIN"
 JSON_ACTION = "JSON"
@@ -35,6 +38,7 @@ REPLACE_ACTION = "REPLACE"
 REPR_ACTION = "REPR"
 REMOVE_ACTION = "REMOVE"
 SAFE_JOIN_ACTION = "SAFE_JOIN"
+SAFE_JOIN_DJANGO_ACTION = "SAFE_JOIN_DJANGO"
 SLICE_ACTION = "SLICE"
 SPLAT_ACTION = "SPLAT"
 SPLIT_ACTION = "SPLIT"
@@ -65,6 +69,8 @@ PROPAGATOR_ACTIONS = {
     REPR_ACTION: ReprPropagator,
     DB_WRITE_ACTION: DBWritePropagator,
     SAFE_JOIN_ACTION: SafeJoinPropagator,
+    SAFE_JOIN_DJANGO_ACTION: SafeJoinDjangoPropagator,
+    CODECS_SPLAT_ACTION: CodecsSplatPropagator,
 }
 
 STREAM_ACTIONS = {
