@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
 from contrast.agent.assess.utils import (
@@ -21,8 +21,6 @@ class AppendPropagator(BasePropagator):
         if len(self.sources) > 1:
             second_source = self.sources[1]
 
-        target_properties = get_properties(self.target)
-
         # if the object and the return are the same length just copy the tags
         # from the object(since nothing from args was added to return)
         if len(self.first_source) == len(self.target):
@@ -46,6 +44,6 @@ class AppendPropagator(BasePropagator):
                 source_properties = get_properties(second_source)
                 if source_properties is not None:
                     copy_tags_to_offset(
-                        target_properties, source_properties.tags, start
+                        self.target_properties, source_properties.tags, start
                     )
-                    copy_events(target_properties, source_properties)
+                    copy_events(self.target_properties, source_properties)
