@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.six import binary_type, string_types, text_type
 
@@ -60,9 +60,6 @@ class BasePropagator(object):
         for source in self.sources:
             if is_tracked(source):
                 track_string(self.target)
-                return True
-
-        return False
 
     def propagate(self):
         """
@@ -71,13 +68,13 @@ class BasePropagator(object):
 
         Some propagators continue to define their own propagate method.
         """
-        target_properties = get_properties(self.target)
-        if target_properties is None:
+        self.target_properties = get_properties(self.target)
+        if self.target_properties is None:
             return
 
         self.first_source = self.sources[0]
         self._propagate()
-        target_properties.cleanup_tags()
+        self.target_properties.cleanup_tags()
 
     def get_parent_ids(self, ret):
         """Some derived classes may need to override this method"""
@@ -85,7 +82,7 @@ class BasePropagator(object):
             self.node, self.preshift.obj, ret, self.preshift.args, self.preshift.kwargs
         )
 
-    def build_event(self, target_properties, ret, frame):
+    def build_event(self, target_properties, ret):
         parent_ids = self.get_parent_ids(ret)
         target_properties.build_event(
             self.node,
@@ -96,7 +93,6 @@ class BasePropagator(object):
             self.preshift.kwargs,
             parent_ids,
             None,
-            frame=frame,
         )
 
     def splat_tags(self, source, ret):
@@ -165,7 +161,7 @@ class BasePropagator(object):
         if self.node.untags:
             self.apply_untags(self.node, self.target)
 
-    def add_tags_and_properties(self, ret, frame):
+    def add_tags_and_properties(self, ret):
         self.add_tags()
 
         target_properties = get_properties(self.target)
@@ -176,7 +172,7 @@ class BasePropagator(object):
 
         target_properties.add_properties(self.node.properties)
 
-        self.build_event(target_properties, ret, frame)
+        self.build_event(target_properties, ret)
 
     def reset_tags(self):
         """
@@ -191,7 +187,7 @@ class BasePropagator(object):
         pass
 
     @fail_safely("Error during propagation")
-    def track_and_propagate(self, ret, frame):
+    def track_and_propagate(self, ret):
         self.track_target()
         self.propagate()
-        self.add_tags_and_properties(ret, frame)
+        self.add_tags_and_properties(ret)
