@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.policy.propagators import BasePropagator
@@ -63,22 +63,19 @@ class FormatPropagator(BasePropagator):
     def track_target(self):
         if tracking_util.recursive_is_tracked(self.preshift.obj) or self.tracked_args:
             track_string(self.target)
-            return True
-        return False
 
-    def propagate(self):
+    def _propagate(self):
         args, kwargs = self.preshift.args, self.preshift.kwargs
 
         # Offset in the target string
         target_offset = 0
 
         source_properties = get_properties(self.preshift.obj)
-        target_properties = get_properties(self.target)
 
         for token in self.tokens:
             if isinstance(token, StringToken):
                 self._propagate_formatted_string_properties(
-                    token, target_offset, source_properties, target_properties
+                    token, target_offset, source_properties, self.target_properties
                 )
                 target_offset += len(token)
             else:  # FormatToken
@@ -90,18 +87,18 @@ class FormatPropagator(BasePropagator):
                     token,
                     target_offset,
                     source_properties,
-                    target_properties,
+                    self.target_properties,
                     formatted=formatted,
                 )
                 self._propagate_format_specifier_properties(
-                    orig_value, target_properties, target_offset
+                    orig_value, self.target_properties, target_offset
                 )
                 target_offset += len(formatted)
 
         if source_properties is not None:
-            copy_events(target_properties, source_properties)
+            copy_events(self.target_properties, source_properties)
 
-        merge_tags(target_properties.tags)
+        merge_tags(self.target_properties.tags)
 
     def _propagate_formatted_string_properties(
         self, token, target_offset, source_properties, target_properties, formatted=None
