@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.policy.propagators import SUPPORTED_TYPES, BasePropagator
 from contrast.utils.assess import tracking_util
@@ -51,28 +51,27 @@ class JoinPropagator(BasePropagator):
             for s in self.sources  # pylint: disable=not-an-iterable
         )
 
-    def propagate(self):
+    def _propagate(self):
 
         # Offset in the target string
         target_offset = 0
 
         base_properties = get_properties(self.preshift.obj)
-        target_properties = get_properties(self.target)
 
         for i, item in enumerate(self.strings_to_join):
             item_properties = get_properties(item)
             if item_properties is not None:
-                self._add_tags(target_properties, item_properties, target_offset)
-                copy_events(target_properties, item_properties)
+                self._add_tags(self.target_properties, item_properties, target_offset)
+                copy_events(self.target_properties, item_properties)
 
             target_offset += len(item)
 
             if i < len(self.strings_to_join) - 1 and base_properties is not None:
-                self._add_tags(target_properties, base_properties, target_offset)
+                self._add_tags(self.target_properties, base_properties, target_offset)
 
             target_offset += len(self.separator)
 
         if base_properties is not None:
-            copy_events(target_properties, base_properties)
+            copy_events(self.target_properties, base_properties)
 
-        merge_tags(target_properties.tags)
+        merge_tags(self.target_properties.tags)
