@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
-from contrast.agent.assess.utils import copy_from, get_properties
+from contrast.agent.assess.utils import copy_from
 
 
 class ReductivePropagator(BasePropagator):
@@ -40,7 +40,4 @@ class ReductivePropagator(BasePropagator):
         if source_index != len(self.first_source):
             remove_ranges.append(AdjustedSpan(target_index, len(self.first_source)))
 
-        target_properties = get_properties(self.target)
-
-        if target_properties:
-            target_properties.delete_tags_at_ranges(remove_ranges)
+        self.target_properties.delete_tags_at_ranges(remove_ranges)
