@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 
@@ -17,7 +17,7 @@ from contrast.agent.assess.utils import (
 )
 from contrast.utils.decorators import fail_safely
 
-from contrast.extern.functools_lru_cache import lru_cache
+from contrast.extern.backports.functools_lru_cache import lru_cache
 
 from .split_propagator import SplitPropagator
 
@@ -180,7 +180,13 @@ def _propagate_sub_tags(
 
 
 def _propagate_sub_events(
-    node, target_properties, orig_properties, repl_properties, target, args, kwargs,
+    node,
+    target_properties,
+    orig_properties,
+    repl_properties,
+    target,
+    args,
+    kwargs,
 ):
 
     parent_ids = []
@@ -240,7 +246,13 @@ def propagate_sub(node, target, repl_results, pattern, repl, string, count=0, **
 
     args = (pattern, repl, string)
     _propagate_sub_events(
-        node, target_properties, orig_properties, repl_properties, target, args, kwargs,
+        node,
+        target_properties,
+        orig_properties,
+        repl_properties,
+        target,
+        args,
+        kwargs,
     )
 
     target_properties.cleanup_tags()
