@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
@@ -32,7 +32,10 @@ class ReplacePropagator(BasePropagator):
             # copy old tags to the new location
             if source_offset != found_idx and orig_properties is not None:
                 self._copy_span_tags_to_offset(
-                    orig_properties, source_offset, found_idx, target_offset,
+                    orig_properties,
+                    source_offset,
+                    found_idx,
+                    target_offset,
                 )
 
             target_offset += found_idx - source_offset
@@ -49,11 +52,13 @@ class ReplacePropagator(BasePropagator):
 
         if source_offset < len(orig_str) and orig_properties is not None:
             self._copy_span_tags_to_offset(
-                orig_properties, source_offset, len(orig_str), target_offset,
+                orig_properties,
+                source_offset,
+                len(orig_str),
+                target_offset,
             )
 
-    def propagate(self):
-
+    def _propagate(self):
         orig_str = self.preshift.obj
         old_str, new_str = self.preshift.args[:2]
 
@@ -63,8 +68,6 @@ class ReplacePropagator(BasePropagator):
         if orig_properties is None and new_properties is None:
             return
 
-        self.target_properties = get_properties(self.target)
-
         self._propagate_tags(
             orig_properties, new_properties, orig_str, old_str, new_str
         )
