@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Propagator used for flask.helpers.safe_join
 
 Tests for this propagator are found in
-test/agent/assess/sanitizers/test_flask_sanitizers.py
+tests/agent/assess/sanitizers/test_flask_sanitizers.py
 """
 import posixpath
-
+from os import path
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.policy.propagators import JoinPropagator
 from contrast.utils.decorators import cached_property
@@ -34,6 +34,8 @@ class SafeJoinPropagator(JoinPropagator):
     to the corresponding range in the target.
     """
 
+    use_abspath = False
+
     def __init__(self, node, preshift, target):
         super(SafeJoinPropagator, self).__init__(node, preshift, target)
         # safe_join looks like '/'.join(directory, *pathnames)
@@ -55,9 +57,16 @@ class SafeJoinPropagator(JoinPropagator):
     def add_tags(self):
         """
         Add sanitizing tags to entire result excluding the base directory
+        In some cases the directory has a relative path `..` so we look for the
+        absolute path.
         """
-        tag_span = AdjustedSpan(len(self.directory), len(self.target))
+        directory = (
+            path.abspath(self.directory)
+            if self.use_abspath and "/.." in self.directory or "/." in self.directory
+            else self.directory
+        )
 
+        tag_span = AdjustedSpan(len(directory), len(self.target))
         if self.node.tags:
             self.apply_tags(self.node, self.target, tag_span)
 
