@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.policy.propagators import BasePropagator
@@ -8,20 +8,13 @@ from contrast.utils.assess.tag_utils import merge_tags
 
 
 class SlicePropagator(BasePropagator):
-    def propagate(self):
-
+    def _propagate(self):
         slice_ = self.preshift.args[0] if self.preshift.args else None
 
         # Offset in the target string
         target_offset = 0
 
         source_properties = get_properties(self.preshift.obj)
-        target_properties = get_properties(self.target)
-
-        if not target_properties:
-            # ignore if target properties are none
-            # likely because the string is interned
-            return
 
         # This is like the coolest thing ever. I found it here:
         # https://stackoverflow.com/a/42883770/4312739
@@ -34,9 +27,9 @@ class SlicePropagator(BasePropagator):
             for name in source_tags:
                 end_offset = target_offset + 1
                 new_span = AdjustedSpan(target_offset, end_offset)
-                target_properties.add_tag(name, new_span)
+                self.target_properties.add_tag(name, new_span)
 
             target_offset += 1
 
-        copy_events(target_properties, source_properties)
-        merge_tags(target_properties.tags)
+        copy_events(self.target_properties, source_properties)
+        merge_tags(self.target_properties.tags)
