@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.six import ensure_binary, iteritems
 
@@ -23,13 +23,13 @@ class SplatPropagator(BasePropagator):
     """
 
     @fail_safely("Splat propagation failed")
-    def track_and_propagate(self, ret, frame):
+    def track_and_propagate(self, ret):
         """
         For splat, we'll track the target ourselves but ensure node tags and untags are applied
         """
         self.track_target()
         self.propagate()
-        self.add_tags_and_properties(ret, frame)
+        self.add_tags_and_properties(ret)
         self.reset_tags()
 
     def track_target(self):
@@ -40,10 +40,7 @@ class SplatPropagator(BasePropagator):
 
         self.target_properties = target_properties
 
-    def propagate(self):
-        if not self.target_properties:
-            return
-
+    def _propagate(self):
         if self._should_copy:
             track_string(self.sources[0])
             copy_from(self.target, self.sources[0], 0, self.node.untags)
