@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.policy.propagators import BasePropagator
 from contrast.agent.assess.utils import (
@@ -26,7 +26,7 @@ class SplitPropagator(BasePropagator):
 
         return tracking_util.recursive_is_tracked(self.preshift.obj)
 
-    def build_event(self, target_properties, tagged, frame):
+    def build_event(self, target_properties, tagged):
         parent_ids = self.get_parent_ids(tagged)
         # For split, the tagged individual string is passed when building the
         # event, but the target is actually the array of strings that was
@@ -40,10 +40,9 @@ class SplitPropagator(BasePropagator):
             self.preshift.kwargs,
             parent_ids,
             None,
-            frame=frame,
         )
 
-    def add_tags_and_properties(self, ret, frame):
+    def add_tags_and_properties(self, ret):
         for target in self.target:
             if self.node.tags:
                 self.apply_tags(self.node, target)
@@ -57,7 +56,7 @@ class SplitPropagator(BasePropagator):
 
             target_properties.add_properties(self.node.properties)
 
-            self.build_event(target_properties, target, frame)
+            self.build_event(target_properties, target)
 
     def propagate(self):
 
