@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import io
 
@@ -31,7 +31,7 @@ def _get_stream_len(stream, curpos):
     return size
 
 
-def _propagate_stream_read(node, preshift, target, tag_span, ret, frame):
+def _propagate_stream_read(node, preshift, target, tag_span, ret):
     """Copies tags and creates event for stream read operations"""
     source_properties = get_properties(preshift.obj)
     target_properties = copy_tags_in_span(target, source_properties, tag_span)
@@ -45,7 +45,7 @@ def _propagate_stream_read(node, preshift, target, tag_span, ret, frame):
     )
 
 
-def propagate_stream_read(method_name, preshift, target, ret, frame):
+def propagate_stream_read(method_name, preshift, target, ret):
     class_name = _get_class_name(preshift.obj)
     node = PropagationNode(
         "io", class_name, True, method_name, "OBJ", "RETURN", "STREAM_READ"
@@ -55,10 +55,10 @@ def propagate_stream_read(method_name, preshift, target, ret, frame):
     startpos = curpos - len(target)
     tag_span = (startpos, curpos)
 
-    _propagate_stream_read(node, preshift, target, tag_span, ret, frame)
+    _propagate_stream_read(node, preshift, target, tag_span, ret)
 
 
-def propagate_stream_readlines(method_name, preshift, target, ret, frame):
+def propagate_stream_readlines(method_name, preshift, target, ret):
     # Nothing to do if there are no results
     if len(target) < 1:
         return
@@ -74,11 +74,11 @@ def propagate_stream_readlines(method_name, preshift, target, ret, frame):
     # Readlines returns a list of lines (including newlines)
     for line in target:
         tag_span = (startpos, startpos + len(line))
-        _propagate_stream_read(node, preshift, line, tag_span, ret, frame)
+        _propagate_stream_read(node, preshift, line, tag_span, ret)
         startpos += len(line)
 
 
-def propagate_stream_getvalue(method_name, preshift, target, ret, frame):
+def propagate_stream_getvalue(method_name, preshift, target, ret):
     class_name = _get_class_name(preshift.obj)
     node = PropagationNode(
         "io", class_name, True, method_name, "OBJ", "RETURN", "STREAM_GETVALUE"
@@ -86,7 +86,7 @@ def propagate_stream_getvalue(method_name, preshift, target, ret, frame):
 
     tag_span = (0, len(target))
 
-    _propagate_stream_read(node, preshift, target, tag_span, ret, frame)
+    _propagate_stream_read(node, preshift, target, tag_span, ret)
 
 
 def _copy_old_props_from_stream(stream, startpos, curpos):
@@ -110,7 +110,7 @@ def _copy_old_props_from_stream(stream, startpos, curpos):
     return new_props
 
 
-def propagate_stream_write(method_name, preshift, target, ret, frame):
+def propagate_stream_write(method_name, preshift, target, ret):
     # This would indicate an error made by the caller, so we can just quit
     if len(preshift.args) < 1:
         return
