@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from pip._vendor.pkg_resources import Requirement
 
@@ -48,6 +48,7 @@ class SourceNode(PolicyNode):
         self.package = package
         self.version = version
         self.type = node_type
+        self.is_cookie_source = self.type == "COOKIE"
 
         if tags is None:
             self.tags = {self.SOURCE_TAG}
@@ -56,14 +57,17 @@ class SourceNode(PolicyNode):
 
         self.validate()
 
-    @staticmethod
-    def create_source_node(module, class_name, column_name, tags, policy_patch=True):
+    @classmethod
+    def dynamic(cls, module, class_name, column_name, tags, policy_patch=True):
+        """
+        Create a dynamic source node, one with the dynamic_source_id property.
+        """
         instance_method = True
         method_name = column_name
         target = "RETURN"
         file_name = "dynamic_source"
 
-        node = SourceNode(
+        node = cls(
             module,
             class_name,
             instance_method,
@@ -140,9 +144,9 @@ class SourceNode(PolicyNode):
                 )
             )
 
-    @staticmethod
-    def from_dict(framework, obj):
-        return SourceNode(
+    @classmethod
+    def from_dict(cls, framework, obj):
+        return cls(
             obj[constants.JSON_MODULE],
             obj.get(constants.JSON_CLASS_NAME, ""),
             obj.get(constants.JSON_INSTANCE_METHOD, True),
