@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import cgi
 
@@ -20,8 +20,9 @@ from contrast.agent.assess.utils import (
 from contrast.agent.policy.constants import OBJECT, RETURN
 from contrast.agent.settings_state import SettingsState
 from contrast.utils.assess.duck_utils import is_iterable, safe_getattr, safe_iterator
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_safely, log_time
 from contrast.utils.string_utils import truncated_signature
+from tempfile import SpooledTemporaryFile
 
 from contrast.extern import structlog as logging
 
@@ -36,7 +37,22 @@ except ImportError:
     EnvironHeaders_types = ()
     FileStorage_types = ()
 
+try:
+    from starlette.datastructures import UploadFile
 
+    FileStorage_types = FileStorage_types + (UploadFile,)
+except ImportError:
+    pass
+
+try:
+    from django.core.files.uploadedfile import InMemoryUploadedFile
+
+    InMemoryUploadedFile_types = (InMemoryUploadedFile,)
+except ImportError:
+    InMemoryUploadedFile_types = ()
+
+
+@log_time("applying source policy")
 def apply(
     source_nodes, self_obj, ret, args, kwargs=None
 ):  # pylint: disable=redefined-builtin
@@ -60,8 +76,27 @@ def apply(
             # it causes massive slowdown. Instead, if we see a FileStorage object
             # come out of a multidict, we track it. We need to track the underlying
             # stream, not the FileStorage object itself.
-            target = target.stream if PY2 else target.stream._file
+            if hasattr(target, "stream"):
+                target = target.stream if PY2 else target.stream._file
+            elif hasattr(target, "file"):
+                # starlette case
+                target = target.file
             source_type = "MULTIPART_CONTENT_DATA"
+        elif isinstance(target, InMemoryUploadedFile_types):
+            # same as above but for django
+            source_type = "MULTIPART_CONTENT_DATA"
+            if hasattr(target, "_name"):
+                cs__apply_source(
+                    context,
+                    node,
+                    target._name,
+                    self_obj,
+                    ret,
+                    args,
+                    kwargs,
+                    source_type=source_type,
+                )
+            target = target.file
 
         if hasattr(target, "cs__source"):
             # Target is already a source, nothing to do
@@ -106,6 +141,9 @@ def apply_stream_source(method_name, target, self_obj, ret, args, kwargs):
     if context is None or not SettingsState().is_assess_enabled():
         return
 
+    if context.stop_source_creation:
+        return
+
     module = self_obj.__class__.__module__
     class_name = self_obj.__class__.__name__
 
@@ -171,10 +209,9 @@ def cs__apply_source(
     source_name=None,
     source_type=None,
 ):
-    # target: {param: test} / QueryDict
-    # self_obj: QueryDict
-    # ret: test
-    # args: param
+
+    if context.stop_source_creation:
+        return
 
     logger.debug("In cs__apply_source for %r", node)
     if source_type is None:
@@ -213,16 +250,29 @@ def _cs__apply_source(
     if not context or not node or target is None:
         return
 
+    if context.stop_source_creation:
+        return
+
     target_properties = get_properties(target)
+    if target_properties is not None:
+        # Discard any preexisting tags or events for this string. This greatly
+        # simplifies reporting by retaining only the most recent source event for each
+        # string
+        target_properties.reset()
     if target_properties is None and is_trackable(target):
         target_properties = track_string(target)
-
     if target_properties is not None:
+        # Need to track what the source is because cookies shouldn't trigger xss
+        target_properties.is_cookie_source = (
+            target_properties.is_cookie_source or node.is_cookie_source
+        )
+
         if not safe_getattr(target, "cs__source", False):
             for tag in adjust_source_tags(node.tags, source_type, source_name):
-                length = len(target)
+                if target_properties.is_cookie_source and tag == "CROSS_SITE":
+                    continue
 
-                target_properties.add_tag(tag, AdjustedSpan(0, length))
+                target_properties.add_tag(tag, AdjustedSpan(0, len(target)))
                 target_properties.add_properties(node.properties)
 
                 logger.debug(
@@ -246,10 +296,12 @@ def _cs__apply_source(
             source_name=source_name,
         )
 
+        context.source_created()
+
         if is_trackable(target):
             set_properties(target, target_properties)
 
-    elif isinstance(target, dict):
+    elif isinstance(target, (dict, Mapping)):
         # This logic is intended to handle the case where the source is a dict
         # that happens to represent request parameters, headers, or cookies.
         # In these cases we want the top-level keys of this dictionary to be
@@ -283,38 +335,17 @@ def _cs__apply_source(
             )
 
     elif isinstance(target, cgi.FieldStorage):
+        # we have patches for this already and we don't want to fall into the
+        # is_iterable case
+        return
+
+    elif isinstance(target, SpooledTemporaryFile):
         # circular import
-        from contrast.utils.assess.stream_utils import (  # noqa
-            ContrastFileProxy,
-            ContrastRawIOProxy,
-            BaseStreamProxy,
-        )
+        from contrast.utils.assess.stream_utils import ContrastFileProxy  # noqa
 
-        if hasattr(target, "filename"):
-            _cs__apply_source(
-                context,
-                node,
-                target.filename,
-                self_obj,
-                ret,
-                source_type,
-                source_name,
-                False,
-                args,
-                kwargs,
-            )
-        if hasattr(target, "file") and not isinstance(target.file, BaseStreamProxy):
-            # In PY2, FieldStorage.file has type `file`. In PY3, it has type FileIO.
-            if hasattr(target.file, "cs__source"):
-                target.file.cs__source = True
-            elif PY2:
-                target.file = ContrastFileProxy(target.file)
-            else:
-                target.file = ContrastRawIOProxy(target.file)
-
-            # TODO: PYT-921 fix so we get the proper source type for Pyramid files
-            # target.file.cs__source_type = node.type
-            target.file.cs__source_tags = node.tags
+        target._file = ContrastFileProxy(target._file)
+        target._file.cs__source_type = "MULTIPART_CONTENT_DATA"
+        target._file.cs__source_tags = node.tags
 
     elif is_iterable(target):
         for value in safe_iterator(target):
