@@ -1,10 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from copy import copy
 
 from contrast.agent.assess.tag import Tag
-from contrast.utils.assess.tag_utils import combine, is_covered, ordered_merge
+from contrast.utils.assess.tag_utils import (
+    combine,
+    is_covered,
+    ordered_merge,
+    intersection,
+)
 
 
 class DefaultAction(object):
@@ -55,15 +60,20 @@ class DefaultAction(object):
         :param desired_tags:
         :return: list of Tag instances
         """
-        tag_ranges = []
 
         if not properties.is_tracked() or not desired_tags:
-            return tag_ranges
+            return []
 
-        for idx in range(properties.last_tagged_index()):
-            tags_at = properties.get_tags_at(idx)
-            if set(desired_tags) <= set(tags_at):
-                tag_ranges.append(Tag(1, idx))
+        trimmed = False
+        tag_ranges = [Tag(properties.last_tagged_index() + 1, 0)]
+
+        for tag in desired_tags:
+            tags = properties.fetch_tags(tag)
+            tag_ranges = intersection(tags, tag_ranges)
+            trimmed = True
+
+        if not trimmed:
+            return []
 
         return combine(tag_ranges)
 
