@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.six import iteritems
 
 import contrast
 from contrast.agent.assess.apply_trigger import cs__apply_trigger
+from contrast.utils.decorators import log_time
 
 
+@log_time("applying trigger policy")
 def apply(
     rule, trigger_nodes, ret, args, kwargs=None
 ):  # pylint: disable=redefined-builtin
@@ -22,15 +24,13 @@ def apply(
     @param args: Tuple containing args passed to trigger function
     @param kwargs: Dict containing kwargs passed to trigger function
     """
-    if kwargs is None:
-        kwargs = {}
+    kwargs = kwargs or {}
 
     context = contrast.CS__CONTEXT_TRACKER.current()
     if context is None:
         return
 
     for node in trigger_nodes:
-
         if node.instance_method:
             self_obj = args[0]
             args = args[1:]  # args[0] is `self` for instance methods
