@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-
-from contrast.utils.object_share import ObjectShare
-
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
+CONTRAST_ASSESS_METHOD_START = "cs__assess_"
+
 
 def build_method_name(method_name):
     """
@@ -16,4 +15,4 @@ def build_method_name(method_name):
     Example:
         cs__assess_append
     """
-    return ObjectShare.CONTRAST_ASSESS_METHOD_START + method_name
+    return CONTRAST_ASSESS_METHOD_START + method_name
