@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 
 from contrast.agent.assess.rules.config.base_config_rule import BaseConfigRule
+from contrast.utils.decorators import fail_safely
 
 
 class BaseFlaskConfigRule(BaseConfigRule):
@@ -31,6 +32,7 @@ class BaseFlaskConfigRule(BaseConfigRule):
     def get_snippet(self, value):
         return 'app.config["{}"] = {!r}'.format(self.SETTINGS_VALUE, value)
 
+    @fail_safely("Failed to apply config rule")
     def apply(self, app):
         value = self.get_config_value(app.config)
         if not self.is_violated(value):
