@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 
 
@@ -12,4 +12,6 @@ class HttpOnlyRuleMixin(object):
         """
         The rule is violated if the value is False or if it is not set at all (None)
         """
+        if self.count_threshold_reached():
+            return False
         return not value
