@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 
 
@@ -14,4 +14,6 @@ class SecureFlagRuleMixin(object):
 
     def is_violated(self, value):
         """Rule is violated if config value is missing (None) or set to False"""
+        if self.count_threshold_reached():
+            return False
         return not value
