@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from datetime import timedelta
 
@@ -16,6 +16,8 @@ class SessionAgeRuleMixin(object):
         Flask represents this value as either a timedelta or as an integer in seconds.
         All other frameworks represent it as an integer representing seconds.
         """
+        if self.count_threshold_reached():
+            return False
         if isinstance(value, timedelta):
             return value > timedelta(minutes=30)
 
