@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.policy import constants
 from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.assess.rules.base_rule import BaseRule
 from contrast.agent.assess.utils import get_properties
-from contrast.api import Finding
+from contrast.api import Finding, send_finding
 from contrast.utils.assess.duck_utils import safe_getattr
 from contrast.utils.decorators import cached_property
 from contrast.utils.string_utils import equals_ignore_case
@@ -42,6 +42,8 @@ class TriggerRule(BaseRule):
         self.disallowed_tags = []
         self.populate_disallowed(disallowed_tags)
 
+        super(TriggerRule, self).__init__()
+
     @property
     def name(self):
         return self._name
@@ -104,6 +106,9 @@ class TriggerRule(BaseRule):
         """
         Determine whether rule was violated based on source object
         """
+        if self.count_threshold_reached():
+            return False
+
         # The rule is violated if the object is marked as source
         if safe_getattr(source, "cs__source", False):
             return True
@@ -137,7 +142,7 @@ class TriggerRule(BaseRule):
         return trigger_nodes
 
     def create_finding(self, properties, node, target, **kwargs):
-        return Finding(self, properties, **kwargs).get_finding_msg()
+        return Finding(self, properties, **kwargs)
 
     def build_and_append_finding(self, context, properties, node, target, **kwargs):
         finding_msg = self.create_finding(properties, node, target, **kwargs)
@@ -148,8 +153,6 @@ class TriggerRule(BaseRule):
             if finding_msg.hash_code == curr_finding.hash_code:
                 return
 
-        context.activity.findings.extend([finding_msg])
-
         logger.debug(
             "Trigger %s detected: %s triggered %s",
             node.name,
@@ -157,6 +160,9 @@ class TriggerRule(BaseRule):
             self.name,
         )
 
+        self.finding_reported()
+        send_finding(finding_msg, context)
+
     JSON_NAME = "name"
     JSON_DISALLOWED_TAGS = "disallowed_tags"
     JSON_REQUIRED_TAGS = "required_tags"
