@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.rules.triggers.trigger_config_rule import TriggerConfigRule
 from contrast.agent.assess.rules.config.session_age_rule import SessionAgeRuleMixin
@@ -11,4 +11,6 @@ class SessionTimeoutRule(TriggerConfigRule, SessionAgeRuleMixin):
         return False
 
     def is_violated(self, node, source, **kwargs):
+        if self.count_threshold_reached():
+            return False
         return SessionAgeRuleMixin.is_violated(self, source)
