@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 
@@ -42,12 +42,9 @@ class TriggerConfigRule(DataflowRule):
         return "{}:{}".format(filename, frame.line_number)
 
     def _create_snippet(self, node, target, event):
-        source = node.sources[0]
-        params = (
-            "{}={}".format(source, target)
-            if isinstance(source, six.string_types)
-            else repr(target)
-        )
+        # Rely only on kwarg param for reporting
+        source = [x for x in node.sources if isinstance(x, six.text_type)][0]
+        params = "{}={}".format(source, target)
 
         method_name = (
             "{}.{}".format(
@@ -72,4 +69,4 @@ class TriggerConfigRule(DataflowRule):
         properties[self.PATH] = self._create_filename(reported_frame)
         properties[self.SNIPPET] = self._create_snippet(node, target, events[-1])
 
-        return Finding(self, properties, **kwargs).get_finding_msg()
+        return Finding(self, properties, **kwargs)
