@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import threading
-import time
 from contrast.agent import scope
 from contrast.utils.decorators import fail_safely
-from contrast.utils.timer import Timer
+from contrast.utils import service_util
+from contrast.utils.timer import now_ms
 
 from contrast.extern import structlog as logging
 
@@ -40,7 +40,7 @@ class Heartbeat(threading.Thread):
 
             while not self.stopped and self.settings.is_agent_config_enabled():
                 self.send_heartbeat()
-                time.sleep(self.get_sleep_time())
+                service_util.sleep(self.get_sleep_time())
 
     @fail_safely("Error sending a heartbeat message")
     def send_heartbeat(self):
@@ -51,6 +51,6 @@ class Heartbeat(threading.Thread):
         # only send after we have not updated after the last interval time set in the config
         if (
             self.settings.last_update is not None
-            and (Timer.now_ms() - self.settings.last_update) > heartbeat_interval_ms
+            and (now_ms() - self.settings.last_update) > heartbeat_interval_ms
         ):
             service_client.send_heartbeat_message()
