@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 import sys
@@ -41,6 +41,9 @@ from contrast.extern import structlog as logging
 logger = logging.getLogger("contrast")
 
 
+BaseMiddleware.MIDDLEWARE_IMPORT_DEPRECATED = True
+
+
 class DjangoBaseMiddleware(BaseMiddleware):
     """
     Base class for all django middlewares.
@@ -94,7 +97,6 @@ class DjangoBaseMiddleware(BaseMiddleware):
 
     def call_with_agent(self, context, request):
         self.log_start_request_analysis(request.path)
-        context.timer.set_start("total")
 
         # For now, django does not track the wsgi.input stream since it's not a true IO
         # stream object and we have other ways of getting the sources we need. No need
