@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from __future__ import print_function
-
-import os
 import platform
 import sys
 
-from contrast import __version__
+from contrast import __version__, AGENT_CURR_WORKING_DIR
 from contrast.agent.patch_controller import disable_assess_patches
 from contrast.agent import patch_controller, service_client, scope
 from contrast.agent.policy.loader import Policy
@@ -22,11 +20,18 @@ from contrast.utils.decorators import cached_property
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
 )
-from contrast.extern.six import PY2
+from contrast.utils.string_utils import truncate
+from contrast.utils.decorators import log_time_cm
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.library_reader.library_reader import LibraryReader
 from contrast.utils.loggers.logger import setup_agent_logger, setup_basic_agent_logger
+from contrast.utils.timer import now_ms_float, now_ms
+from contrast.assess_extensions import cs_str
 
+if sys.version_info >= (3, 7) and sys.version_info < (3, 10):
+    from contrast.agent.telemetry import Telemetry
+else:
+    Telemetry = None
 # initialize a basic logger until config is parsed
 logger = setup_basic_agent_logger()
 
@@ -46,6 +51,7 @@ class BaseMiddleware(RoutesMixin):
     Pre -> get_response -> post
     """
 
+    MIDDLEWARE_IMPORT_DEPRECATED = False
     _loaded = False
     app_name = ""  # This should be overridden by child classes
 
@@ -56,21 +62,47 @@ class BaseMiddleware(RoutesMixin):
         "A security filter prevented original response from being returned."
     )
     LOGS_SEPARATOR = "-" * 120
-    PY2_DEPRECATION_MSG = "[Contrast Security] [DEPRECATION] Support for Python 2.7  will be removed in 2021. Please contact Customer Support prior if you require continued support."
+
+    MIDDLEWARE_DEPRECATION_MSG = (
+        "[Contrast Security] [DEPRECATION] Agent version 5.0.0 will drop support "
+        "for middleware imports through contrast.agent.middlewares "
+        "in December 2021. See https://docs.contrastsecurity.com/en/python-middleware.html "
+        "for updated installation instructions."
+    )
+
+    PYTHON_DEPRECATION_MSG = (
+        "[Contrast Security] [DEPRECATION] Agent version 5.0.0 will drop support for Python {}.{} in December 2021. "
+        "Please contact Customer Support prior if you require continued support."
+    )
 
     def __init__(self):
-        # use _loaded to call our middleware only once because of runserver and WSGIHandler being initialized twice.
-        if BaseMiddleware._loaded:
-            return
+        """
+        If this method is called more than once per process, we use the _loaded
+        flag to only run the following work once:
+            - turning on service
+            - library analysis thread initialization
+            - turning on patches
+            - hardcoded rule providers
+            - scanning config rules
 
-        # id to distinguish middlewares created by different processes
+        the following work will be done every time:
+            - any logging
+            - attribute definition
+            - loading common configuration
+            - initializing settings
+        """
+        if BaseMiddleware._loaded:
+            logger.warning(
+                "Contrast Agent middleware initialized more than once per process."
+            )
+
+        # id will be different across processes but also for multiple middlewares
+        # within the same process
         self.id = id(self)
 
-        self.log_deprecation()
         self.log_initialize()
 
         self.settings = None
-
         self.routes = {}
         self.first_request = True
 
@@ -85,31 +117,59 @@ class BaseMiddleware(RoutesMixin):
         setup_agent_logger(self.settings.config)
         self.settings.config.log_config()
 
-        if not self.initialize_service_client():
+        if sys.version_info[0:2] <= (3, 6):
+            self.log_deprecation(
+                self.PYTHON_DEPRECATION_MSG.format(
+                    sys.version_info.major, sys.version_info.minor
+                )
+            )
+
+        if self.MIDDLEWARE_IMPORT_DEPRECATED:
+            self.log_middleware_deprecation()
+
+        if not BaseMiddleware._loaded:
+            logger.debug(
+                "Use contextvars for Scope and Request Context storage: %s",
+                cs_str.USE_CONTEXTVARS,
+            )
+
+            if cs_str.USE_CONTEXTVARS:
+                cs_str.init_contrast_scope_cvars()
+
+        if not BaseMiddleware._loaded and not self.initialize_service_client():
             logger.error("Unable to initialize Contrast Agent.")
             return
 
         # This call must happen after initializing SR so we have all data to log
         self.log_environment()
-
-        self.initialize_libraries()
+        self.warn_for_misleading_config()
 
         if (
-            self.settings.config
-            and self.settings.config.get("protect.enable", True)
-            and self.settings.config.get("assess.enable")
+            not BaseMiddleware._loaded
+            and sys.version_info >= (3, 7)
+            and sys.version_info < (3, 10)
         ):
-            logger.warning("Assess and Protect both enabled in agent configuration")
-            logger.warning("Defaulting to Protect behavior only")
+            self.telemetry = Telemetry()
+            self.telemetry.start()
 
-        patch_controller.enable_patches()
+        if not BaseMiddleware._loaded:
+            self.initialize_libraries()
+
+            patch_controller.enable_patches()
 
         if self.settings.is_assess_enabled():
-            enable_providers()
-            self.scan_configs()
+            # For now agent runtime starts before config scanning
+            # this will be reset when time_limit_threshold is reached,
+            # it doesn't simbolize the total agent runtime for all time.
+            self.settings.agent_runtime_window = now_ms()
+
+            if not BaseMiddleware._loaded:
+                enable_providers()
+                self.scan_configs()
 
         self.log_finish_initialize()
 
+        self.request_start_time = None
         BaseMiddleware._loaded = True
 
     def initialize_settings(self, app_name):
@@ -138,15 +198,37 @@ class BaseMiddleware(RoutesMixin):
             return False
         return True
 
+    def warn_for_misleading_config(self):
+        protect_enabled = self.settings.is_protect_enabled()
+        assess_enabled = self.settings.is_assess_enabled()
+
+        logger.info("Protect: %s", protect_enabled)
+        logger.info("Assess: %s", assess_enabled)
+
+        if protect_enabled and self.settings.config.get("assess.enable"):
+            logger.warning("Protect is running but Assess is enabled in local config")
+            logger.warning("Defaulting to Protect behavior only")
+
+        if not protect_enabled and self.settings.config.get("protect.enable", True):
+            logger.warning("Protect enabled in local config but disabled by Teamserver")
+
+        if (
+            self.settings.is_agent_config_enabled()
+            and not protect_enabled
+            and not assess_enabled
+        ):
+            logger.warning("Neither Protect nor Assess is running")
+
     def log_environment(self):
         """
         Log current working directory, python version and pip version
         """
         banner = "{0}ENVIRONMENT{0}".format("-" * 50)
         logger.debug(banner)
-        logger.debug("Current Working Dir: %s", os.getcwd())
+        logger.debug("Current Working Dir: %s", AGENT_CURR_WORKING_DIR)
         logger.debug("Python Version: %s", sys.version)
         logger.debug("Framework Version: %s", self.settings.framework)
+        logger.debug("Server Version: %s", self.settings.server)
         logger.debug("Contrast Python Agent Version: %s", __version__)
         logger.debug(
             "Contrast Service Version %s",
@@ -171,8 +253,9 @@ class BaseMiddleware(RoutesMixin):
         if not self.settings.is_analyze_libs_enabled():
             return
 
-        # Passing callback to send message due to a circular import issue, and a deadlock
-        # occurring if something is imported inside of a function running in this thread
+        # Passing callback to send message due to a circular import issue, and a
+        # deadlock occurring if something is imported inside of a function running in
+        # this thread
         self.library_reader = LibraryReader(
             send_message_func=service_client.send_messages
         )
@@ -182,11 +265,12 @@ class BaseMiddleware(RoutesMixin):
         """
         Agent is considered enabled if all of the following are true:
         1. config value for 'enable' is True (or empty, defaults to True)
-            (meaning no errors during initialization process including initial connection to Speedracer)
+            (meaning no errors during initialization process including initial
+            connection to Speedracer)
         2. ServiceClient connection to Speedracer is True
 
-        NOTE: If #3 is false (the connection to Speedracer is down at any time during the request cycle) then
-        the agent is automatically disabled.
+        NOTE: If #3 is false (the connection to Speedracer is down at any time during
+        the request cycle) then the agent is automatically disabled.
         """
         if self.settings is None:
             return False
@@ -207,15 +291,16 @@ class BaseMiddleware(RoutesMixin):
 
     def call_without_agent(self):
         """
-        If Agent is either disabled or not initialized due to either entire settings initialization failing
-        or just loggers failing, then we should print to stdout that the Agent is not running.
+        If Agent is either disabled or not initialized due to either entire settings
+        initialization failing or just loggers failing, then we should print to stdout
+        that the Agent is not running.
 
-        In the case of the agent is disabled by a reaction from SR, we have to disable assess patches here
-        because checking for context inside of our builtin string patches is much more expensive to do since
-        they are called very frequently.
+        In the case of the agent is disabled by a reaction from SR, we have to disable
+        assess patches here because checking for context inside of our builtin string
+        patches is much more expensive to do since they are called very frequently.
 
-        The agent does not set context when this function is called so all other patches (e.g propagators) that check
-        context shouldn't run.
+        The agent does not set context when this function is called so all other patches
+        (e.g propagators) that check context shouldn't run.
         """
         disable_assess_patches()
 
@@ -242,6 +327,12 @@ class BaseMiddleware(RoutesMixin):
             service_client.send_messages(self.final_messages(context))
 
     def final_messages(self, context):
+        # Request body is truncated to not overwhelm ContrastUI.
+        raw_request_body = context.activity.http_request.request_body_binary
+        context.activity.http_request.request_body_binary = truncate(
+            raw_request_body, length=4096
+        )
+
         final_messages = [
             context.server_activity,
             context.activity,
@@ -292,7 +383,8 @@ class BaseMiddleware(RoutesMixin):
 
     def prefilter(self, context):
         """
-        Prefilter - AKA input analysis - is performed mostly in Speedracer but partly in the agent.
+        Prefilter - AKA input analysis - is performed mostly in Speedracer but partly
+        in the agent.
 
         This is PROTECT only.
 
@@ -304,16 +396,9 @@ class BaseMiddleware(RoutesMixin):
         if not self.settings.is_protect_enabled():
             return
 
-        context.timer.set_start("prefilter")
-
-        logger.debug("Running prefilter.")
-        context.speedracer_input_analysis = get_input_analysis()
-
-        self.agent_prefilter()
-
-        logger.debug("Completed prefilter.")
-
-        context.timer.set_end("prefilter")
+        with log_time_cm("protect prefilter"):
+            context.speedracer_input_analysis = get_input_analysis()
+            self.agent_prefilter()
 
     def agent_prefilter(self):
         """
@@ -344,26 +429,23 @@ class BaseMiddleware(RoutesMixin):
         """
         For all postfilter enabled rules.
         """
-        context.timer.set_start("postfilter")
+        with log_time_cm("postfilter"):
+            if self.settings.is_protect_enabled():
+                try:
+                    self.postfilter_defend()
+                except SecurityException as e:
+                    logger.exception("PROTECT: threw security exception in postfilter")
+                    raise e
+                except Exception:
+                    logger.exception("PROTECT: threw exception in postfilter")
 
-        if self.settings.is_protect_enabled():
-            try:
-                self.postfilter_defend()
-            except SecurityException as e:
-                logger.exception("PROTECT: threw security exception in postfilter")
-                raise e
-            except Exception:
-                logger.exception("PROTECT: threw exception in postfilter")
-
-        if self.settings.is_assess_enabled():
-            scope.enter_contrast_scope()
-            try:
-                self.postfilter_assess(context)
-            except Exception:
-                logger.exception("ASSESS: threw exception in postfilter")
-            scope.exit_contrast_scope()
-
-        context.timer.set_end("postfilter")
+            if self.settings.is_assess_enabled():
+                scope.enter_contrast_scope()
+                try:
+                    self.postfilter_assess(context)
+                except Exception:
+                    logger.exception("ASSESS: threw exception in postfilter")
+                scope.exit_contrast_scope()
 
     def _process_trigger_handler(self, handler):
         """
@@ -451,6 +533,7 @@ class BaseMiddleware(RoutesMixin):
             "/pdf",
             "/x-javascript",
             "/x-json",
+            "/plain",
         ]
 
         content_type = context.response.headers.get("content-type", "")
@@ -495,19 +578,24 @@ class BaseMiddleware(RoutesMixin):
                 raise SecurityException(None, message=msg)
 
     def log_start_request_analysis(self, request_path):
+        self.request_start_time = now_ms_float()
         logger.debug("Beginning request analysis", request_path=request_path)
 
     def log_end_request_analysis(self, request_path):
+        request_end_time = now_ms_float()
+
         logger.debug(
-            "Ending request analysis", request_path=request_path,
+            "Ending request analysis",
+            request_path=request_path,
         )
 
-    def log_deprecation(self):
-        if PY2:
-            warn_color = "\033[91m"
-            end_color = "\033[0m"
-            print("\n{}{}{}\n".format(warn_color, self.PY2_DEPRECATION_MSG, end_color))
-            logger.warning(self.PY2_DEPRECATION_MSG)
+        elapsed_time = request_end_time - self.request_start_time
+
+        logger.debug(
+            "elapsed time request analysis ms",
+            elapsed_time=elapsed_time,
+            request_path=request_path,
+        )
 
     def log_initialize(self):
         logger.info(
@@ -532,3 +620,16 @@ class BaseMiddleware(RoutesMixin):
         Those that do should override this method.
         """
         logger.debug("No config scanning rules for %s", self.__class__.__name__)
+
+    @staticmethod
+    def log_deprecation(msg):
+        warn_color = "\033[91m"
+        end_color = "\033[0m"
+
+        print("\n{}{}{}\n".format(warn_color, msg, end_color))
+
+        logger.warning(msg)
+
+    @staticmethod
+    def log_middleware_deprecation():
+        BaseMiddleware.log_deprecation(BaseMiddleware.MIDDLEWARE_DEPRECATION_MSG)
