@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
 from contrast.agent import scope
@@ -9,7 +9,7 @@ from contrast.agent.middlewares.response_wrappers.django_response_wrapper import
     DjangoResponseWrapper,
 )
 from contrast.agent.request_context import RequestContext
-from contrast.utils.decorators import cached_property
+from contrast.utils.decorators import cached_property, log_time_cm
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
 )
@@ -49,9 +49,8 @@ class DjangoMiddleware(DjangoBaseMiddleware):
         try:
             self.prefilter(context)
 
-            logger.debug("Start app code and get response")
-            response = self.get_response(request)
-            logger.debug("Finished app code and get response")
+            with log_time_cm("app code and get response"):
+                response = self.get_response(request)
 
             with scope.contrast_scope():
                 wrapped_response = DjangoResponseWrapper(response)
@@ -62,8 +61,6 @@ class DjangoMiddleware(DjangoBaseMiddleware):
 
             self.check_for_blocked(context)
 
-            context.timer.set_end("total")
-
         except ContrastServiceException as e:
             logger.warning(e)
             return self.call_without_agent(request)
