@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import deque
 from copy import copy
@@ -12,7 +12,7 @@ from contrast.agent.middlewares.route_coverage.coverage_utils import (
     DEFAULT_ROUTE_METHODS,
 )
 from contrast.agent.settings_state import SettingsState
-from contrast.extern.functools_lru_cache import lru_cache
+from contrast.extern.backports.functools_lru_cache import lru_cache
 
 from contrast.extern import structlog as logging
 
