@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.middlewares.route_coverage.coverage_utils import (
     CoverageUtils,
     DEFAULT_ROUTE_METHODS,
 )
+from contrast.utils.decorators import fail_safely
 from pyramid.interfaces import IView, IViewClassifier, IRouteRequest, IRoutesMapper
 from zope.interface import Interface
 
@@ -72,3 +73,40 @@ def build_pyramid_route(pyramid_route_name, view_func):
     method_arg_names = CoverageUtils.build_args_from_function(view_func)
 
     return pyramid_route_name + method_arg_names
+
+
+class PyramidRoutesMixin(object):
+    """
+    Mixin for methods required by both the classic and WSGI-based Pyramid middlewares
+    """
+
+    @fail_safely("Unable to get route coverage", return_value={})
+    def get_route_coverage(self):
+        return create_pyramid_routes(self.registry)
+
+    @fail_safely("Unable to find new routes")
+    def get_view_func(self, request):
+        path = request.environ.get("PATH_INFO", "")
+        if not path:
+            logger.debug("No path info for pyramid request")
+            return None
+
+        mapper = self.registry.queryUtility(IRoutesMapper)
+        routes = mapper.get_routes()
+
+        # Ideally we would like to call get_route but
+        # there is no direct relationship between the wsgi
+        # request path and the name of the route so we must
+        # iterate over all the routes to find it by the path
+        # pyramid_route = mapper.get_route(name)
+
+        matching_routes = [x for x in routes if x.path == path]
+        if not matching_routes:
+            return None
+
+        return get_view_func(self.registry, matching_routes[0])
+
+    @fail_safely("Unable to build route", return_value="")
+    def build_route(self, view_func, url):
+        route_name = url.replace("/", "")
+        return build_pyramid_route(route_name, view_func)
