@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
 from contrast.api import Finding
-
+from contrast.utils.decorators import log_time
 
 from contrast.extern import structlog as logging
 
@@ -16,6 +16,7 @@ class RoutesMixin(object):
     Route coverage is assess only.
     """
 
+    @log_time("route coverage")
     def handle_routes(self, context, request):
         """
         Method that should run for all middlewares immediately after the application executes.
