@@ -1,8 +1,16 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import inspect
 
+try:
+    from inspect import iscoroutinefunction
+except ImportError:
+
+    def iscoroutinefunction(f):
+        return False
+
+
 from contrast.extern.six.moves import builtins
 from contrast.extern.wrapt import register_post_import_hook
 
@@ -12,25 +20,21 @@ try:
 except ImportError:
     cached_property = None
 
+from contrast.agent.policy import patch_manager
 from contrast.agent.policy.loader import Policy
 from contrast.agent.protect.policy import apply_protect_patch
 from contrast.agent.assess.policy.patches import (
-    assess_method,
-    assess_classmethod,
-    assess_deadzone,
-    assess_property,
+    build_assess_method,
+    build_assess_classmethod,
+    build_assess_deadzone,
+    build_assess_property_fget,
     apply_cached_property,
 )
 from contrast.agent.settings_state import SettingsState
 from contrast.agent.assess.policy.source_node import SourceNode
 from contrast.agent.assess.policy.utils import build_method_name
 from contrast.assess_extensions import smart_setattr
-
-from contrast.utils.patch_utils import (
-    patch_cls_or_instance,
-    patch_property,
-    repatch_module,
-)
+from contrast.utils.patch_utils import repatch_module
 
 
 from contrast.extern import structlog as logging
@@ -131,7 +135,13 @@ def apply_assess_patch(patch_site, patch_policy):
         old_method = patch_site.__dict__[method_name]
     else:
         # get old function/property/method
-        old_method = getattr(patch_site, patch_policy.method_name)
+        try:
+            old_method = getattr(patch_site, patch_policy.method_name)
+        except AttributeError:
+            # Some python/framework versions or platforms will not have certain
+            # methods/funcs defined so we skip them here. This isn't a failure
+            # so logging is not necessary.
+            return False
 
     if not save_original_method(patch_site, cs_method_name, old_method):
         return False
@@ -139,29 +149,34 @@ def apply_assess_patch(patch_site, patch_policy):
     if isinstance(old_method, property):
         # newer versions of werkzeug cached_property inherit from property
         # so these are handled here
-        new_method = assess_property
+        fget = build_assess_property_fget(patch_policy.method_name, patch_policy)
+        new_method = property(fget=fget, fset=old_method.fset, fdel=old_method.fdel)
     elif cached_property is not None and isinstance(old_method, cached_property):
         # Handle the case in older versions of werkzeug where cached_propery does
         # not inherit from property.
         return apply_cached_property(patch_site, patch_policy, method_name, old_method)
     elif class_method:
-        new_method = assess_classmethod
+        new_method = classmethod(build_assess_classmethod(old_method, patch_policy))
+    elif static_method:
+        new_method = staticmethod(build_assess_classmethod(old_method, patch_policy))
+    elif iscoroutinefunction(old_method):
+        # we do the import here to prevent loading this file in pre-3.7!
+        from contrast.agent.assess.policy.async_patches import build_assess_async_method
+
+        new_method = build_assess_async_method(old_method, patch_policy)
     else:
         # We only support deadzones for methods/functions right now.
         if patch_policy.is_deadzone and not patch_policy.deadzone_enabled:
             return False
-        new_method = assess_deadzone if patch_policy.is_deadzone else assess_method
+
+        new_method = (
+            build_assess_deadzone(old_method, patch_policy)
+            if patch_policy.is_deadzone
+            else build_assess_method(old_method, patch_policy)
+        )
 
     try:
-        patch_cls_or_instance(
-            patch_site,
-            method_name,
-            new_function=new_method,
-            patch_policy=patch_policy,
-            static_method=static_method,
-            class_method=class_method,
-            assess_patch=True,
-        )
+        patch_manager.patch(patch_site, method_name, new_method)
         logger.debug("added patch to %s.%s", patch_site, method_name)
     except Exception as e:
         logger.debug(
@@ -265,21 +280,33 @@ def apply_patch_to_dynamic_property(class_to_patch, property_name, tags):
     This means that the next time the cls.property is called,
     we will inject ourselves and run source policy.
 
-    NOTE: adding the dynamic source to Policy() BEFORE calling patch_property
-    is critical order, given that we have to patch with the policy instance
-    that has this dynamic source. This could later be modified to not need
-    this requirement.
+    NOTE: adding the dynamic source to Policy() BEFORE patching is critical order,
+    given that we have to patch with the policy instance that has this dynamic source.
+    This could later be modified to not need this requirement.
     """
     module = class_to_patch.__module__
     class_name = class_to_patch.__name__
 
-    dynamic_source_node = SourceNode.create_source_node(
+    dynamic_source_node = SourceNode.dynamic(
         module, class_name, property_name, tags, policy_patch=False
     )
 
     policy = Policy()
     patch_policy = policy.add_source_node(dynamic_source_node)
 
-    patch_property(class_to_patch, property_name, assess_property, patch_policy)
+    orig_property = getattr(class_to_patch, property_name)
+
+    def fset(cls_instance, value):
+        # while good instinct would lead us to use setattr here instead of __dict__,
+        # doing so does not work because we are in fact within a setter!
+        cls_instance.__dict__[property_name] = value
+
+    new_property = property(
+        fget=build_assess_property_fget(property_name, patch_policy),
+        fset=fset,
+        fdel=getattr(orig_property, "fdel", None),
+    )
+
+    patch_manager.patch(class_to_patch, property_name, new_property)
 
     return True
