@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import OrderedDict, defaultdict
 import json
@@ -26,9 +26,10 @@ from contrast.agent.assess.rules.triggers import (
     HttpOnlyRule,
     SecureFlagMissingRule,
     SessionTimeoutRule,
+    SessionRewritingRule,
 )
 from contrast.utils.singleton import Singleton
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import cached_property, fail_safely
 
 from contrast.extern import structlog as logging
 
@@ -46,6 +47,7 @@ class Policy(Singleton):
         "httponly": HttpOnlyRule,
         "session-timeout": SessionTimeoutRule,
         "secure-flag-missing": SecureFlagMissingRule,
+        "session-rewriting": SessionRewritingRule,
     }
 
     def init(self):
@@ -171,3 +173,11 @@ class Policy(Singleton):
         node.validate()
         self.sources.append(node)
         return self.process_node(node)
+
+    @cached_property
+    def string_method_nodes(self):
+        return [
+            node
+            for node in self.policy_by_module["BUILTIN"]
+            if node.class_name == "str"
+        ]
