@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import defaultdict
-from inspect import isclass
+from importlib import import_module
 
 from contrast.assess_extensions import smart_setattr
 from contrast.utils import Namespace
+from contrast.utils.object_utils import get_name
 
 from contrast.extern import structlog as logging
 
@@ -17,9 +18,6 @@ class module(Namespace):
     patch_map = {}
     # map from id(patch) -> orig_attr
     inverse_patch_map = {}
-    # list of modules we've visited, whose relevant
-    # attributes we've at least initially patched
-    visited_modules = set()
     # allows lookup of patches by owner ID
     # this is what enables reverse patching
     patches_by_owner = defaultdict(set)
@@ -29,8 +27,8 @@ class module(Namespace):
     patches_by_name = defaultdict(set)
 
 
-def get_name(obj):
-    return "{0.__module__}.{0.__name__}".format(obj) if isclass(obj) else obj.__name__
+def get_patch(obj):
+    return module.patch_map.get(id(obj))
 
 
 def patch(owner, name, patch=None):
@@ -54,7 +52,7 @@ def patch(owner, name, patch=None):
         )
         return
     if patch is None:
-        patch = module.patch_map.get(id(underlying))
+        patch = get_patch(underlying)
         if patch is None:
             # TODO: PYT-692 investigate unexpected patching
             logger.debug(
@@ -81,14 +79,7 @@ def _reverse_patch(owner, name):
     :param owner: module or class that owns the attribute being reverse patched
     :param name: name of the attribute as a string
     """
-    patch = as_func(getattr(owner, name, None))
-
-    if patch is None:
-        # TODO: PYT-692 investigate unexpected patching
-        logger.debug(
-            "WARNING: failed to reverse patch %s of %s: no such attribute", name, owner
-        )
-        return
+    patch = as_func(getattr(owner, name))
 
     if not is_patched(patch):
         return
@@ -124,6 +115,24 @@ def reverse_patches_by_owner(owner):
         _reverse_patch(owner, name)
 
 
+def reverse_all_patches():
+    """
+    Reverse every patch managed by the patch_manager.
+
+    Currently, this only reverses direct references to attributes we've patched. It's
+    still possible that this doesn't cover cases where we patched an extra reference to
+    an attribute via repatching.
+    """
+    for owner_name in module.patches_by_name.copy():
+        try:
+            owner = import_module(owner_name)
+        except ImportError:
+            module_name, _, attr_name = owner_name.rpartition(".")
+            owner = getattr(import_module(module_name), attr_name)
+
+        reverse_patches_by_owner(owner)
+
+
 def register_patch(owner, name, orig_attr):
     """
     Register patch in the patch map to prevent us from patching twice
@@ -132,13 +141,14 @@ def register_patch(owner, name, orig_attr):
     :param name: name of the patched attribute
     :param orig_attr: original attribute, which is being replaced
     """
-    mark_visited(owner)
-
     patch = as_func(getattr(owner, name))
     underlying = as_func(orig_attr)
 
     if id(module.patch_map.get(id(underlying))) == id(patch):
+        # this is the case for repatching: the original attribute already has a
+        # registered patch and that patch matches the one we just applied to it
         return
+
     if patch is underlying:
         # TODO: PYT-692 investigate unexpected patching
         logger.debug(
@@ -168,9 +178,14 @@ def _deregister_patch(patch, owner, name, orig_attr):
         del module.patches_by_owner[id(owner)]
         del module.patches_by_name[owner_name]
 
-    del module.patch_map[id(underlying)]
+    # Safety check for the case where we actually have two different patches that
+    # correspond to the same original function (e.g. some of the codecs patches). In
+    # these cases, there are two entries in the inverse_patch_map, but only one in the
+    # patch_map. This isn't ideal, but it prevents errors when reverse patching.
+    if id(underlying) in module.patch_map:
+        del module.patch_map[id(underlying)]
+
     del module.inverse_patch_map[id(patch)]
-    remove_visited(owner)
 
     from contrast.agent.policy.applicator import remove_patch_location
 
@@ -201,38 +216,6 @@ def has_associated_patch(attr):
     return id(as_func(attr)) in module.patch_map
 
 
-def is_visited(module_):
-    """
-    Check if we've visited a given module.
-
-    :param module_: module object in question
-    :return: True if we've visited this module in the context of patching,
-        False otherwise
-    """
-    return id(module_) in module.visited_modules
-
-
-def mark_visited(module_):
-    """
-    Mark a module as visited.
-
-    :param module_: module object in question
-    """
-    module.visited_modules.add(id(module_))
-
-
-def remove_visited(module_):
-    if is_visited(module_):
-        module.visited_modules.remove(id(module_))
-
-
-def clear_visited_modules():
-    """
-    Clear the set of visited modules.
-    """
-    module.visited_modules.clear()
-
-
 def as_func(attr):
     """
     In python 2, we can't trust the id of unbound methods. For example, if we have
