@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.six import PY2, PY3, integer_types
 
@@ -7,7 +7,11 @@ from contrast.agent.policy import constants
 from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.constants import ALL_ARGS, OBJECT, RETURN
 from contrast.api.dtm_pb2 import TraceEvent
-from contrast.utils.object_share import ObjectShare
+
+
+UNDERSCORE = "_"
+COMMA = ","
+COLON = ":"
 
 
 class PolicyNode(object):
@@ -61,6 +65,7 @@ class PolicyNode(object):
         self.python2_only = python2_only
         self.python3_only = python3_only
 
+        self.skip_stacktrace = False
         self.properties = {}
 
     @property
@@ -124,7 +129,7 @@ class PolicyNode(object):
         if not str_rep:
             return []
 
-        for item in str_rep.split(ObjectShare.COMMA):
+        for item in str_rep.split(COMMA):
             if item == constants.OBJECT:
                 ret.append(item)
 
@@ -138,13 +143,13 @@ class PolicyNode(object):
                 ret.append(item)
 
             # handle ARG_#
-            elif item.startswith(constants.ARG + ObjectShare.UNDERSCORE):
-                arg_num = item.split(ObjectShare.UNDERSCORE)[1]
+            elif item.startswith(constants.ARG + UNDERSCORE):
+                arg_num = item.split(UNDERSCORE)[1]
                 ret.append(int(arg_num))
 
             # handle KWARG:name
-            elif item.startswith(constants.KWARG + ObjectShare.COLON):
-                kwarg_name = item.split(ObjectShare.COLON)[1]
+            elif item.startswith(constants.KWARG + COLON):
+                kwarg_name = item.split(COLON)[1]
                 ret.append(kwarg_name)
 
             else:
@@ -168,7 +173,11 @@ class PolicyNode(object):
         if not str_rep:
             return ""
         if str_rep.startswith(
-            (constants.KWARG, constants.ALL_ARGS, constants.ALL_KWARGS,)
+            (
+                constants.KWARG,
+                constants.ALL_ARGS,
+                constants.ALL_KWARGS,
+            )
         ):
             return "P0"
 
