@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 from contrast.extern.six import integer_types
@@ -36,6 +36,7 @@ class TriggerNode(PolicyNode):
         python2_only=False,
         python3_only=False,
         protect_mode=False,
+        unsafe_default=False,
     ):
         super(TriggerNode, self).__init__(
             module,
@@ -62,6 +63,7 @@ class TriggerNode(PolicyNode):
         self.rule = rule
 
         self.protect_mode = protect_mode
+        self.unsafe_default = unsafe_default
 
         self.validate()
 
@@ -102,7 +104,19 @@ class TriggerNode(PolicyNode):
                 sources.append(args[source])
             elif kwargs and source in kwargs:
                 sources.append(kwargs[source])
+            elif (
+                isinstance(source, str)  # only consider kwarg sources
+                and self.unsafe_default
+                and source not in sources
+            ):
+                # if the default argument for this source is unsafe and we landed
+                # here, we should trigger a finding. To do so, we add `None`,
+                # with the assumption that most triggers will use `None`
+                # as a default, but this won't always be correct. We may add a
+                # trigger that uses a boolean as a default.
 
+                # TODO: PYT-1764 special machinery to know what the default really is
+                sources.append(None)
         return sources
 
     def get_protect_sources(self, args, kwargs):
@@ -114,9 +128,9 @@ class TriggerNode(PolicyNode):
     def trigger_action(self):
         return self.TRIGGER_ACTIONS.get(self.action)
 
-    @staticmethod
-    def from_dict(obj, dataflow=True, rule=None):
-        return TriggerNode(
+    @classmethod
+    def from_dict(cls, obj, dataflow=True, rule=None):
+        return cls(
             obj[constants.JSON_MODULE],
             obj.get(constants.JSON_CLASS_NAME, ""),
             obj.get(constants.JSON_INSTANCE_METHOD, True),
@@ -131,4 +145,5 @@ class TriggerNode(PolicyNode):
             python2_only=obj.get(constants.JSON_PY2_ONLY, False),
             python3_only=obj.get(constants.JSON_PY3_ONLY, False),
             protect_mode=obj.get(constants.JSON_PROTECT_MODE, False),
+            unsafe_default=obj.get(constants.JSON_UNSAFE_DEFAULT, False),
         )
