@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import inspect
 import os
@@ -10,10 +10,10 @@ from contrast.api.settings_pb2 import ProtectionRule
 from contrast.api.settings_pb2 import InputAnalysisResult
 from contrast.extern import six
 from contrast.utils.decorators import fail_safely, fail_quietly
-from contrast.utils.decorators import cached_property, set_context
+from contrast.utils.decorators import cached_property
 from contrast.utils.exceptions.security_exception import SecurityException
-from contrast.utils.stack_trace_utils import StackTraceUtils
-
+from contrast.utils.stack_trace_utils import build_and_clean_stack
+from contrast.utils.timer import now_ms
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
@@ -25,6 +25,10 @@ POSTFILTER_RULES = frozenset(
     [ProtectionRule.BLOCK, ProtectionRule.MONITOR, ProtectionRule.PERMIT]
 )
 
+PREFILTER = "prefilter"
+INFILTER = "infilter"
+POSTFILTER = "postfilter"
+
 
 class BaseRule(object):
     """
@@ -37,11 +41,6 @@ class BaseRule(object):
         self.settings = settings
         self.settings.defend_rules[self.name] = self
 
-        # attributes updated in set_context
-        self.in_prefilter = False
-        self.in_infilter = False
-        self.in_postfilter = False
-
     @property
     def name(self):
         return self.NAME
@@ -158,7 +157,6 @@ class BaseRule(object):
             for m in code_exclusions
         )
 
-    @set_context("in_prefilter")
     def prefilter(self):
         """
         Scans the input analysis for the rule and looks for matched attack signatures
@@ -167,7 +165,7 @@ class BaseRule(object):
         """
         logger.debug("PROTECT: Prefilter for %s", self.name)
 
-        attack = self.find_attack()
+        attack = self.find_attack(analysis_stage=PREFILTER)
         if attack is None or len(attack.samples) == 0:
             return
 
@@ -178,7 +176,6 @@ class BaseRule(object):
                 self, "Rule triggered in prefilter. Request blocked."
             )
 
-    @set_context("in_infilter")
     def infilter(self, match_string, **kwargs):
         """
         Scans the input analysis for the rule and looks for matched attack signatures. The call to this method may be
@@ -189,7 +186,7 @@ class BaseRule(object):
 
         logger.debug("PROTECT: Infilter for %s", self.name)
 
-        attack = self.find_attack(match_string, **kwargs)
+        attack = self.find_attack(match_string, analysis_stage=INFILTER, **kwargs)
         if attack is None or len(attack.samples) == 0:
             return
 
@@ -250,7 +247,6 @@ class BaseRule(object):
         """Only rules for database support increase the query count"""
         pass
 
-    @set_context("in_postfilter")
     def postfilter(self):
         """
         Scans the input analysis for the rule and looks for matched attack signatures
@@ -262,7 +258,7 @@ class BaseRule(object):
         if self.mode in [ProtectionRule.NO_ACTION, ProtectionRule.PERMIT]:
             return
 
-        attack = self.find_attack()
+        attack = self.find_attack(analysis_state=POSTFILTER)
         if attack is None or len(attack.samples) == 0:
             return
 
@@ -273,7 +269,7 @@ class BaseRule(object):
                 self, "Rule triggered in postfilter. {} blocked.".format(self.name)
             )
 
-    def find_attack(self, candidate_string=None, **kwargs):
+    def find_attack(self, candidate_string=None, analysis_stage=None, **kwargs):
         """
         Finds the attacker in the original string if present
         """
@@ -284,14 +280,17 @@ class BaseRule(object):
             return None
 
         # if rule mode is BAP, only speedracer determines if we should block
-        if self.in_prefilter and self.mode == ProtectionRule.BLOCK_AT_PERIMETER:
+        if (
+            analysis_stage == PREFILTER
+            and self.mode == ProtectionRule.BLOCK_AT_PERIMETER
+        ):
             return None
 
         evaluations_for_rule = self.evaluations_for_rule()
 
         attack = None
         for evaluation in evaluations_for_rule:
-            if self.in_postfilter:
+            if analysis_stage == POSTFILTER:
                 if (
                     evaluation.attack_count > 0
                     or evaluation.input_type == UserInput.QUERYSTRING
@@ -372,15 +371,14 @@ class BaseRule(object):
         )
 
     def build_base_sample(self, evaluation, prebuilt_stack=None):
-        stack = prebuilt_stack if prebuilt_stack else StackTraceUtils.build(ignore=True)
+        stack = prebuilt_stack if prebuilt_stack else build_and_clean_stack()
         sample = RaspRuleSample()
         sample.stack_trace_elements.extend(stack)
 
         if evaluation:
             sample.user_input.CopyFrom(self.build_user_input(evaluation))
 
-        context = contrast.CS__CONTEXT_TRACKER.current()
-        sample.timestamp_ms = context.timer.start_ms
+        sample.timestamp_ms = now_ms()
 
         return sample
 
