@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
 from contrast.agent.protect.rule.base_rule import BaseRule, UserInput
-from contrast.utils.decorators import set_context
 
 from contrast.extern import structlog as logging
 
@@ -17,7 +16,6 @@ class MethodTampering(BaseRule):
     def __init__(self, settings):
         BaseRule.__init__(self, settings)
 
-    @set_context("in_postfilter")
     def postfilter(self):
         """
         At postfilter we generate activity if input analysis was found and depending on application response code.
@@ -35,11 +33,14 @@ class MethodTampering(BaseRule):
         for evaluation in evaluations_for_rule:
             if str(response_code).startswith("4") or str(response_code).startswith("5"):
                 attack = self.build_attack_without_match(
-                    method=evaluation.value, response_code=response_code,
+                    method=evaluation.value,
+                    response_code=response_code,
                 )
             else:
                 attack = self.build_attack_with_match(
-                    None, method=evaluation.value, response_code=response_code,
+                    None,
+                    method=evaluation.value,
+                    response_code=response_code,
                 )
             self._append_to_activity(attack)
 
