@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-import os
-
+from contrast import AGENT_CURR_WORKING_DIR
 from contrast.extern.six import string_types
 from contrast.agent.protect.mixins.path_traversal_sink_features import (
     PathTraversalSinkFeatures,
 )
-from contrast.agent.protect.rule.base_rule import BaseRule
+from contrast.agent.protect.rule.base_rule import BaseRule, INFILTER
 
 from contrast.utils.decorators import fail_quietly
 
@@ -22,12 +21,14 @@ class PathTraversal(BaseRule, PathTraversalSinkFeatures):
     def __init__(self, settings):
         BaseRule.__init__(self, settings)
 
-    def find_attack(self, candidate_string=None, **kwargs):
+    def find_attack(self, candidate_string=None, analysis_stage=None, **kwargs):
         """
         Finds the attacker in the original string if present
         """
-        attack = super(PathTraversal, self).find_attack(candidate_string, **kwargs)
-        if self.in_infilter:
+        attack = super(PathTraversal, self).find_attack(
+            candidate_string, analysis_stage=analysis_stage, **kwargs
+        )
+        if analysis_stage == INFILTER and candidate_string:
             attack = self.check_sink_features(candidate_string, attack)
 
         return attack
@@ -84,6 +85,8 @@ def actionable_path(path):
 
 
 def _safer_abs_paths():
-    pwd = os.getcwd()
-
-    return ["{}/{}".format(pwd, item) for item in SAFE_PATHS] if pwd else []
+    return (
+        ["{}/{}".format(AGENT_CURR_WORKING_DIR, item) for item in SAFE_PATHS]
+        if AGENT_CURR_WORKING_DIR
+        else []
+    )
