@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 
@@ -7,7 +7,7 @@ from contrast.extern import webob
 from contrast.extern import six
 
 from contrast.api import dtm_pb2
-from contrast.utils.timer import Timer
+from contrast.utils.timer import now_ms
 from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
 
 from contrast.extern import structlog as logging
@@ -29,7 +29,7 @@ class Request(webob.BaseRequest):
         self._document_type = None
         self._normalized_uri = None
 
-        self.timestamp_ms = Timer.now_ms()
+        self.timestamp_ms = now_ms()
 
     def get_dtm(self):
         """
