@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Controller for global scope state
@@ -97,7 +97,7 @@ enter_eval_scope.__doc__ = """
 
 def in_scope():
     """Indicates we are in either contrast scope or propagation scope"""
-    return in_contrast_scope() or in_propagation_scope()
+    return cs_str.in_contrast_or_propagation_scope()
 
 
 @contextmanager
