@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 import socket
 import struct
-import time
 
 import contrast
 from contrast.agent.connection_status import ConnectionStatus
@@ -26,8 +25,9 @@ from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
 )
 from contrast.utils.singleton import Singleton
+from contrast.utils import service_util
 from contrast.utils.service_util import ServiceUtil
-from contrast.utils.timer import Timer
+from contrast.utils.timer import now_ms
 
 from contrast.extern import structlog as logging
 
@@ -69,7 +69,10 @@ class _ServiceState(Singleton):
         Return the path for where the application is running, either configured
         in common config or by looking at the current working dir.
         """
-        return SettingsState().config.get("application.path") or os.getcwd()
+        return (
+            SettingsState().config.get("application.path")
+            or contrast.AGENT_CURR_WORKING_DIR
+        )
 
     @property
     def resend_startup(self):
@@ -108,7 +111,7 @@ class _ServiceState(Singleton):
         to use the bundled service and turning it on if so.
 
         If the app isn't configured to use the bundled service or after turning the bundled service on,
-        agent sends initial messages to Contrast Service (AgentStartup, ApplicationCreate, ApplicationUpdate)
+        agent sends initial messages to Contrast Service (AgentStartup, ApplicationCreate)
         to determine that it is successfully able to communicate with it.
 
         If configuration specifies an external service, whatever manages the external service should handle cases
@@ -118,22 +121,47 @@ class _ServiceState(Singleton):
 
         """
         settings = SettingsState()
-        responses = []
-
-        initial_messages = self.build_initial_messages()
 
         if settings.is_bundled_enabled and self.local_service_configured:
             self.bundled_flag = "bundled"
 
             if not self.start_service():
-                # if bundled service is configured but it could not be started, return empty responses
-                return responses
+                # if bundled service is configured but it could not be started,
+                # then we don't have service data to process, so we should not
+                # continue on with Agent startup.
+                raise ContrastServiceException
 
         logger.info("Will communicate with Contrast Service")
+        self._build_and_send_startup_msgs()
 
-        # it's only necessasry to wait to send messages when using the bundled service because it takes a bit to start up
+    def _build_and_send_startup_msgs(self):
+        settings = SettingsState()
+
+        first_msg = self._build_agent_startup_msg(settings)
+
+        # it's only necessasry to wait to send messages when using the bundled service
+        # because it takes a bit to start up
         wait = 1 if self.bundled_flag == "bundled" else 0
-        return self.send_messages_retry(initial_messages, wait=wait)
+
+        responses = self.send_messages_retry([first_msg], wait=wait)
+        if not responses:
+            # If we received no response for the first message, we should not
+            # try to send the second message.
+            raise ContrastServiceException
+
+        settings.process_responses(responses)
+
+        # now that we have server features from first_msg we can build + send app create
+        second_msg = self._build_app_create_msg(settings)
+
+        # no wait because we know SR is already up
+        responses = self.send_messages_retry([second_msg])
+        if not responses:
+            # If we received no response for the second message, we should not
+            # continue on with Agent startup.
+            raise ContrastServiceException
+
+        settings.process_responses(responses)
 
     def send_messages_retry(self, messages, attempts=0, wait=0, raise_exception=True):
         """
@@ -166,7 +194,7 @@ class _ServiceState(Singleton):
         :return: list of responses from Speedracer
         :side effect: ContrastServiceException if raise_exception is True
         """
-        time.sleep(wait)
+        service_util.sleep(wait)
 
         try:
             return self._send_messages(messages)
@@ -203,8 +231,6 @@ class _ServiceState(Singleton):
         :return: json string of the response
         :side effect: ContrastServiceException if any problems connecting / sending messages occur
         """
-        settings = SettingsState()
-
         packed = message.SerializeToString()
         sock = None
         try:
@@ -233,9 +259,6 @@ class _ServiceState(Singleton):
     def _send_messages(self, messages):
         responses = []
         messages = [messages] if not isinstance(messages, list) else messages
-        if self.resend_startup:
-            logger.debug("Resending startup messages")
-            messages = self.build_initial_messages() + messages
 
         to_send = self.update_messages(messages)
 
@@ -311,7 +334,7 @@ class _ServiceState(Singleton):
         message.client_id = self.client_id
         message.client_number = 1
         message.client_total = 1
-        message.timestamp_ms = Timer.now_ms()
+        message.timestamp_ms = now_ms()
         message.pid = settings.pid
 
         self.count += 1
@@ -323,7 +346,7 @@ class _ServiceState(Singleton):
         message = self.build_empty_message()
 
         if isinstance(agent_message, Activity):
-            agent_message.duration_ms = Timer.now_ms()
+            agent_message.duration_ms = now_ms()
             message.activity.CopyFrom(agent_message)
 
         if isinstance(agent_message, AgentStartup):
@@ -367,7 +390,7 @@ class _ServiceState(Singleton):
 
         return updated
 
-    def _build_server_start_message(self, settings):
+    def _build_agent_startup_msg(self, settings):
         agent_startup = AgentStartup()
 
         agent_startup.server_name = settings.get_server_name()
@@ -399,7 +422,7 @@ class _ServiceState(Singleton):
 
         return agent_startup
 
-    def _build_startup_message(self, settings):
+    def _build_app_create_msg(self, settings):
         create = ApplicationCreate()
         create.group = settings.config.get("application.group", "")
         create.app_version = settings.config.get("application.version", "")
@@ -411,16 +434,12 @@ class _ServiceState(Singleton):
         create.session_id = settings.config.get_session_id()
         create.session_metadata = settings.config.get_session_metadata()
 
+        # instrumentation mode
+        create.mode.protect = settings.is_protect_enabled()
+        create.mode.assess = settings.is_assess_enabled()
+
         return create
 
-    def build_initial_messages(self):
-        settings = SettingsState()
-
-        return [
-            self._build_server_start_message(settings),
-            self._build_startup_message(settings),
-        ]
-
 
 def is_connected():
     return _ServiceState().connection_status.connected
@@ -454,7 +473,13 @@ def build_update_message(routes):
 
 def send_messages_get_responses(messages):
     """Send messages to service and return responses"""
-    return _ServiceState().send_messages_retry(messages, raise_exception=False)
+    service_state = _ServiceState()
+
+    if service_state.resend_startup:
+        logger.debug("Resending startup messages")
+        service_state._build_and_send_startup_msgs()
+
+    return service_state.send_messages_retry(messages, raise_exception=False)
 
 
 def send_messages(messages):
@@ -485,13 +510,4 @@ def send_startup_messages():
 
     :return: bool if successfuly able to send initial messages and receive and process responses.
     """
-    settings = SettingsState()
-
-    responses = _ServiceState().initialize_and_send_messages()
-    if responses:
-        settings.process_responses(responses)
-        return True
-
-    # if we did not receive any responses from Speedracer, then we don't have any server or startup
-    # messages to process, so we should not continue on with Agent setup.
-    raise ContrastServiceException
+    _ServiceState().initialize_and_send_messages()
