@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 
-from contrast.agent.framework import Framework
+from contrast import AGENT_CURR_WORKING_DIR
+from contrast.agent.framework import Framework, Server
 from contrast.agent.heartbeat import Heartbeat
 from contrast.agent.protect.mixins.REP_settings import SettingsREPMixin
 from contrast.agent.protect.rule.rules_builder import RulesBuilder
@@ -15,10 +16,11 @@ from contrast.api.settings_pb2 import (
     ServerFeatures,
 )
 from contrast.configuration import AgentConfig
+from contrast.utils.decorators import cached_property
 from contrast.utils.loggers.logger import reset_agent_logger
 from contrast.utils.singleton import Singleton
 from contrast.utils.string_utils import truncate
-
+from contrast.utils.timer import now_ms
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
@@ -34,6 +36,7 @@ class SettingsState(Singleton, SettingsREPMixin):
         self.last_update = None
         self.heartbeat = None
         self.framework = Framework()
+        self.server = Server()
         self.sys_module_count = 0
 
         # Features and Settings from Service
@@ -61,6 +64,8 @@ class SettingsState(Singleton, SettingsREPMixin):
         # Initialize application metadata
         self.app_name = self.get_app_name(app_name)
 
+        self.agent_runtime_window = now_ms()
+
         logger.info("Contrast Agent finished loading settings.")
 
     def _is_defend_enabled_in_server_features(self):
@@ -73,7 +78,25 @@ class SettingsState(Singleton, SettingsREPMixin):
     def is_agent_config_enabled(self):
         return self.config.get("enable", True)
 
-    @property
+    @cached_property
+    def max_sources(self):
+        return self.config.get("assess.max_context_source_events")
+
+    @cached_property
+    def max_propagation(self):
+        return self.config.get("assess.max_propagation_events")
+
+    @cached_property
+    def max_vulnerability_count(self):
+        """Max number of vulnerabilities per rule type to report for one
+        agent run `time_limit_threshold` time period"""
+        return self.config.get("assess.max_rule_reported")
+
+    @cached_property
+    def agent_runtime_threshold(self):
+        return self.config.get("assess.time_limit_threshold")
+
+    @cached_property
     def is_bundled_enabled(self):
         """The default across agents is to use the bundled service by default"""
         return self.config.get("agent.service.enable", True)
@@ -89,10 +112,6 @@ class SettingsState(Singleton, SettingsREPMixin):
         return os.getpid()
 
     def get_app_name(self, app_name):
-        # Used in DARPA-Screener to set the app's name (so TS can tell the difference between 5 instances of the app)
-        if os.environ.get("CONTRASTSECURITY_APP_NAME"):
-            return os.environ.get("CONTRASTSECURITY_APP_NAME")
-
         if self.config.get("application.name"):
             return self.config.get("application.name")
 
@@ -188,15 +207,10 @@ class SettingsState(Singleton, SettingsREPMixin):
             self.accumulator_settings = data.accumulator_settings
 
     def update_logger_from_features(self):
-        # Python does not support TRACE level so we use DEBUG for now
-        log_level = (
-            "DEBUG"
-            if self.server_features.log_level == "TRACE"
-            else self.server_features.log_level
+        logger_reset = reset_agent_logger(
+            self.server_features.log_file, self.server_features.log_level
         )
 
-        logger_reset = reset_agent_logger(self.server_features.log_file, log_level)
-
         if logger_reset:
             self.config.log_config()
 
@@ -211,7 +225,8 @@ class SettingsState(Singleton, SettingsREPMixin):
         inventory.analyze_libraries = false: Disables only library analysis/reporting
         """
         return (
-            self.config.get("inventory.analyze_libraries", True)
+            self.config is not None
+            and self.config.get("inventory.analyze_libraries", True)
             and self.is_inventory_enabled()
         )
 
@@ -275,7 +290,9 @@ class SettingsState(Singleton, SettingsREPMixin):
         Default is root
         """
         if self.server_path is None:
-            self.server_path = self.config.get("server.path") or truncate(os.getcwd())
+            self.server_path = self.config.get("server.path") or truncate(
+                AGENT_CURR_WORKING_DIR
+            )
 
         return self.server_path
 
@@ -305,3 +322,18 @@ class SettingsState(Singleton, SettingsREPMixin):
             if self.disabled_assess_rules
             else rule_id in self.application_settings.disabled_assess_rules
         )
+
+    def is_collect_stacktraces_all(self):
+        return (
+            self.config is not None and self.config.get("assess.stacktraces") == "ALL"
+        )
+
+    def is_collect_stacktraces_some(self):
+        return (
+            self.config is not None and self.config.get("assess.stacktraces") == "SOME"
+        )
+
+    def is_collect_stacktraces_none(self):
+        return (
+            self.config is not None and self.config.get("assess.stacktraces") == "NONE"
+        )
