@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.six import iteritems
-from contrast.api.dtm_pb2 import Finding as FindingDtm
+from contrast.api.dtm_pb2 import Activity, Finding as FindingDtm
+
 from contrast.utils.string_utils import protobuf_safe
 
 from contrast.agent.policy.constants import (
@@ -21,26 +22,25 @@ class Finding(object):
     Wrapper around api.dtm_pb2.Finding
     """
 
-    def __init__(self, rule, properties, **kwargs):
-        self.finding = FindingDtm()
+    def __new__(cls, rule, properties, **kwargs):
+        finding = FindingDtm()
 
-        rule.add_events_to_finding(self.finding, **kwargs)
+        rule.add_events_to_finding(finding, **kwargs)
 
-        self.finding.rule_id = protobuf_safe(rule.name)
+        finding.rule_id = protobuf_safe(rule.name)
 
         for key, value in iteritems(properties):
-            self.finding.properties[key] = value
+            finding.properties[key] = value
 
         hash_code = rule.generate_preflight_hash(**kwargs)
 
-        self.finding.hash_code = hash_code
-        self.finding.preflight = ",".join([rule.name, hash_code])
+        finding.hash_code = hash_code
+        finding.preflight = ",".join([rule.name, hash_code])
 
         logger.debug("Created finding for %s", rule.name)
-        logger.debug("initial preflight value: %s", self.finding.preflight)
+        logger.debug("initial preflight value: %s", finding.preflight)
 
-    def get_finding_msg(self):
-        return self.finding
+        return finding
 
     @staticmethod
     def pick_version(finding):
@@ -64,3 +64,25 @@ class Finding(object):
 
         # dataflow finding without routes
         return MINIMUM_FINDING_VERSION
+
+
+def send_finding(finding, context=None):
+    """
+    Send a finding by either appending it to request context
+    OR sending it immediately.
+
+    :param finding:  api.dtm_pb2.Finding instance
+    :param context: Request context instance
+    :return: None
+    """
+    # Import here to prevent circular import.
+    from contrast.agent.service_client import send_messages
+    
+    if context:
+        # Once RequestContext is deprecated, this flow can be removed.
+        context.activity.findings.extend([finding])
+    else:
+        activity = Activity()
+        activity.findings.extend([finding])
+
+        send_messages([activity])
