@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
 from contrast.agent.assess.apply_trigger import build_finding
@@ -7,7 +7,7 @@ from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy.analysis import skip_analysis
 
 
-def apply_rule(string, ptr_val, frame):
+def apply_rule(string, ptr_val):
     """
     Applies unsafe-code-execution rule for exec statement in PY2
 
@@ -52,5 +52,4 @@ def apply_rule(string, ptr_val, frame):
                 args,
                 kwargs,
                 target_properties=props,
-                frame=frame,
             )
