@@ -1,7 +1,7 @@
 /*
-* Copyright © 2020 Contrast Security, Inc.
-* See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-*/
+ * Copyright © 2021 Contrast Security, Inc.
+ * See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+ */
 /* Python requires its own header to always be included first */
 #define PY_SSIZE_T_CLEAN
 #include <Python.h>
@@ -26,7 +26,6 @@
         }                                                           \
     } while (0);
 
-
 PyObject *set_attr_on_type(PyObject *self, PyObject *args) {
     PyTypeObject *type = NULL;
     PyObject *name = NULL;
@@ -50,8 +49,7 @@ PyObject *set_attr_on_type(PyObject *self, PyObject *args) {
     Py_RETURN_NONE;
 }
 
-
-PyObject *enable(PyObject *self, PyObject *args, PyObject *kwargs) {
+PyObject *initialize(PyObject *self, PyObject *args, PyObject *kwargs) {
     PyObject *logger = NULL;
     funchook_t *funchook = NULL;
     char *keywords[] = {"logger", NULL};
@@ -77,19 +75,33 @@ PyObject *enable(PyObject *self, PyObject *args, PyObject *kwargs) {
         return NULL;
     }
 
+    return PyCapsule_New((void *)funchook, NULL, NULL);
+}
+
+PyObject *enable_required_hooks(PyObject *self, PyObject *arg) {
+    funchook_t *funchook = NULL;
+
+    UNPACK_FUNCHOOK_CAPSULE;
+
     apply_or_fail(apply_cat_patch, funchook);
+    apply_or_fail(apply_repeat_patch, funchook);
     apply_or_fail(apply_format_patch, funchook);
     apply_or_fail(apply_subscript_patch, funchook);
-    apply_or_fail(apply_unicode_patches, funchook);
-    apply_or_fail(apply_bytes_patches, funchook);
-    apply_or_fail(apply_bytearray_patches, funchook);
     apply_or_fail(apply_stream_patches, funchook);
     apply_or_fail(apply_repr_patches, funchook);
+    apply_or_fail(apply_cast_patches, funchook);
 #ifdef PY2
     apply_or_fail(apply_exec_patches, funchook);
-    apply_or_fail(apply_cast_patches, funchook);
 #endif
 
+    Py_RETURN_NONE;
+}
+
+PyObject *install(PyObject *self, PyObject *arg) {
+    funchook_t *funchook = NULL;
+
+    UNPACK_FUNCHOOK_CAPSULE;
+
     if (funchook_install(funchook, 0) != FUNCHOOK_ERROR_SUCCESS) {
         log_exception(
             PyExc_RuntimeError,
@@ -101,23 +113,13 @@ PyObject *enable(PyObject *self, PyObject *args, PyObject *kwargs) {
 
     log_debug("installed assess patches");
 
-    return PyCapsule_New((void *)funchook, NULL, NULL);
+    Py_RETURN_NONE;
 }
 
-
 PyObject *disable(PyObject *self, PyObject *arg) {
-
     funchook_t *funchook = NULL;
 
-    if (!PyCapsule_IsValid(arg, NULL)) {
-        log_exception(PyExc_TypeError, "Expected funchook container");
-        return NULL;
-    }
-
-    if ((funchook = (funchook_t *)PyCapsule_GetPointer(arg, NULL)) == NULL) {
-        log_exception(PyExc_RuntimeError, "Failed to get funchook from container");
-        return NULL;
-    }
+    UNPACK_FUNCHOOK_CAPSULE;
 
     if (funchook_uninstall(funchook, 0) != FUNCHOOK_ERROR_SUCCESS) {
         log_exception(
