@@ -1,7 +1,7 @@
 /*
-* Copyright © 2020 Contrast Security, Inc.
-* See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-*/
+ * Copyright © 2021 Contrast Security, Inc.
+ * See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+ */
 /* Python requires its own header to always be included first */
 #define PY_SSIZE_T_CLEAN
 #include <Python.h>
@@ -10,19 +10,17 @@
 #include <contrast/assess/propagate.h>
 #include <contrast/assess/scope.h>
 
-
 #if PY_MAJOR_VERSION >= 3
 #define PY3
 #else
 #define PY2
 #endif
 
-
 #define CONTRAST_MODULE_NAME "contrast"
 #define STRING_TRACKER_NAME "STRING_TRACKER"
 #define TRACK_METHOD_NAME "track"
 
-#define POLICY_MODULE_NAME "contrast.agent.assess.policy.propagation_policy"
+#define POLICY_MODULE_NAME "contrast.agent.assess.policy.string_propagation"
 #define PROPAGATE_NAME "propagate"
 
 static PyObject *string_tracker = NULL;
@@ -35,7 +33,6 @@ static PyObject *exec_hook_module = NULL;
 static int init_exec_hook(void);
 #endif
 
-
 int init_propagate() {
     int retcode = -1;
 
@@ -56,7 +53,6 @@ int init_propagate() {
     return retcode;
 }
 
-
 int init_string_tracker() {
     PyObject *contrast_module = NULL;
     int retcode = -1;
@@ -88,7 +84,6 @@ cleanup_and_exit:
     return retcode;
 }
 
-
 int init_propagation() {
     if (policy_module != NULL) {
         log_exception(PyExc_RuntimeError, "policy module already initialized");
@@ -105,7 +100,6 @@ int init_propagation() {
     return 0;
 }
 
-
 #ifdef PY2
 static int init_exec_hook() {
     if (exec_hook_module != NULL) {
@@ -124,7 +118,6 @@ static int init_exec_hook() {
 }
 #endif
 
-
 void teardown_propagate() {
     Py_XDECREF(string_tracker);
     Py_XDECREF(policy_module);
@@ -136,7 +129,6 @@ void teardown_propagate() {
 #endif
 }
 
-
 inline int is_tracked(PyObject *source) {
     if (source == NULL || string_tracker == NULL)
         return 0;
@@ -149,28 +141,75 @@ inline int is_tracked(PyObject *source) {
     return PySequence_Contains(string_tracker, source);
 }
 
-
 static inline bool need_to_pack(PyObject *obj) {
-    return (!PySequence_Check(obj) ||
+    return (
+        !PySequence_Check(obj) ||
 #ifdef PY3
-            PyBytes_Check(obj) ||
+        PyBytes_Check(obj) ||
 #else
-            PyString_Check(obj) ||
+        PyString_Check(obj) ||
 #endif
-            PyUnicode_Check(obj) ||
-            PyByteArray_Check(obj));
+        PyUnicode_Check(obj) || PyByteArray_Check(obj));
 }
 
+void call_string_propagator(
+    char *prop_method_name,
+    PyObject *source,
+    PyObject *newstr,
+    PyObject *hook_args,
+    PyObject *hook_kwargs) {
+    PyObject *result;
+    PyObject *prop_hook_args;
+    int free_hook_args = 0;
 
-static inline PyObject *get_frame(void) {
-    PyThreadState *tstate = PyThreadState_GET();
-    return (tstate == NULL || tstate->frame == NULL) ? Py_None : (PyObject *)tstate->frame;
+    /* No Python API calls should happen in this function prior to this check */
+    if (!should_propagate())
+        return;
+
+    enter_propagation_scope();
+    enter_contrast_scope();
+
+    if (hook_args == NULL) {
+        prop_hook_args = Py_None;
+    } else if (need_to_pack(hook_args)) {
+        prop_hook_args = PyTuple_Pack(1, hook_args);
+        free_hook_args = 1;
+    } else {
+        prop_hook_args = hook_args;
+    }
+
+    result = PyObject_CallMethod(
+        policy_module,
+        prop_method_name,
+        "OOOOO",
+        newstr,                              /* target */
+        (source == NULL ? Py_None : source), /* self_obj */
+        newstr,                              /* ret */
+        /* args */
+        prop_hook_args,
+        /* kwargs */
+        (hook_kwargs == NULL ? Py_None : hook_kwargs));
+
+    if (result == NULL) {
+        PyErr_PrintEx(0);
+        log_error("failed to propagate: %s", prop_method_name);
+    }
+
+    exit_contrast_scope();
+    exit_propagation_scope();
+
+    Py_XDECREF(result);
+    if (free_hook_args) {
+        Py_XDECREF(prop_hook_args);
+    }
 }
 
-
-static void call_propagate(char *prop_method_name, const char *event_name,
-                           PyObject *source, PyObject *newstr,
-                           PyObject *hook_args, PyObject *hook_kwargs) {
+static void call_propagate_stream(
+    const char *event_name,
+    PyObject *source,
+    PyObject *newstr,
+    PyObject *hook_args,
+    PyObject *hook_kwargs) {
     PyObject *result;
     PyObject *prop_hook_args;
     int free_hook_args = 0;
@@ -182,21 +221,22 @@ static void call_propagate(char *prop_method_name, const char *event_name,
     else if (need_to_pack(hook_args)) {
         prop_hook_args = PyTuple_Pack(1, hook_args);
         free_hook_args = 1;
-    }
-    else
+    } else
         prop_hook_args = hook_args;
 
     /* def propagate(method_name, target, obj, ret, args, kwargs) */
-    result = PyObject_CallMethod(policy_module, prop_method_name, "sOOOOOO",
-                                 event_name,      /* method_name */
-                                 newstr,          /* target */
-                                 (source == NULL ? Py_None : source),  /* self_obj */
-                                 newstr,          /* ret */
-                                 get_frame(),     /* frame */
-                                 /* args */
-                                 prop_hook_args,
-                                 /* kwargs */
-                                 (hook_kwargs == NULL ? Py_None : hook_kwargs));
+    result = PyObject_CallMethod(
+        policy_module,
+        "propagate_stream",
+        "sOOOOO",
+        event_name,                          /* method_name */
+        newstr,                              /* target */
+        (source == NULL ? Py_None : source), /* self_obj */
+        newstr,                              /* ret */
+        /* args */
+        prop_hook_args,
+        /* kwargs */
+        (hook_kwargs == NULL ? Py_None : hook_kwargs));
 
     if (result == NULL) {
         PyErr_PrintEx(0);
@@ -207,33 +247,9 @@ static void call_propagate(char *prop_method_name, const char *event_name,
     Py_XDECREF(result);
     if (free_hook_args)
         Py_XDECREF(prop_hook_args);
-
 }
 
-
-void propagate_result(const char *event_name, PyObject *source,
-                      PyObject *newstr, PyObject *hook_args,
-                      PyObject *hook_kwargs) {
-
-    /* No Python API calls should happen in this function prior to this check */
-    if (!should_propagate())
-        return;
-
-    enter_propagation_scope();
-
-#ifdef ASSESS_DEBUG
-    log_debug("propagate result event: %s", event_name);
-    /* This causes problems with encode in Py27. Fix later. */
-    //log_debug("propagate result source: %s", PyObject_Str(source));
-#endif /* ASSESS_DEBUG */
-
-    call_propagate("propagate", event_name, source, newstr, hook_args, hook_kwargs);
-
-    exit_propagation_scope();
-}
-
-
-void propagate_concat(PyObject *l, PyObject *r, PyObject *result) {
+void propagate_concat(PyObject *l, PyObject *r, PyObject *result, char *propagator) {
     PyObject *args;
 
     if (!should_propagate())
@@ -245,15 +261,29 @@ void propagate_concat(PyObject *l, PyObject *r, PyObject *result) {
     if (!is_tracked(l) && !is_tracked(r))
         return;
 
-    enter_propagation_scope();
-
     args = PyTuple_Pack(1, r);
 
-    call_propagate("propagate", "concat", l, result, args, Py_None);
+    call_string_propagator(propagator, l, result, args, NULL);
 
-    exit_propagation_scope();
+    Py_XDECREF(args);
 }
 
+PyObject *propagate_repeat(
+    ssizeargfunc orig_repeat, PyObject *self, Py_ssize_t n, char *propagator) {
+    PyObject *args;
+
+    PyObject *result = orig_repeat(self, n);
+
+    if (result == NULL)
+        return result;
+
+    args = Py_BuildValue("(n)", n);
+
+    call_string_propagator(propagator, self, result, args, Py_None);
+
+    Py_XDECREF(args);
+    return result;
+}
 
 static int has_attr_and_true(PyObject *stream, const char *attrname) {
     PyObject *attr;
@@ -273,7 +303,6 @@ static int has_attr_and_true(PyObject *stream, const char *attrname) {
     return result;
 }
 
-
 static int stream_tracked(PyObject *stream) {
     if (has_attr_and_true(stream, "cs__tracked"))
         return 1;
@@ -284,10 +313,12 @@ static int stream_tracked(PyObject *stream) {
     return 0;
 }
 
-
-void propagate_stream(const char *event_name, PyObject *source,
-                      PyObject *result, PyObject *hook_args,
-                      PyObject *hook_kwargs) {
+void propagate_stream(
+    const char *event_name,
+    PyObject *source,
+    PyObject *result,
+    PyObject *hook_args,
+    PyObject *hook_kwargs) {
 
     if (!should_propagate())
         return;
@@ -299,11 +330,10 @@ void propagate_stream(const char *event_name, PyObject *source,
         return;
 
     enter_propagation_scope();
-    call_propagate("propagate_stream", event_name, source, result, hook_args, hook_kwargs);
+    call_propagate_stream(event_name, source, result, hook_args, hook_kwargs);
     exit_propagation_scope();
 }
 
-
 void create_stream_source_event(PyObject *stream, PyObject *args, PyObject *kwargs) {
     PyObject *result;
 
@@ -312,10 +342,13 @@ void create_stream_source_event(PyObject *stream, PyObject *args, PyObject *kwar
 
     enter_contrast_scope();
 
-    result = PyObject_CallMethod(policy_module, "create_stream_source_event",
-                                 "OOOO", stream, get_frame(),
-                                 (args == NULL ? Py_None : args),
-                                 (kwargs == NULL ? Py_None : kwargs));
+    result = PyObject_CallMethod(
+        policy_module,
+        "create_stream_source_event",
+        "OOO",
+        stream,
+        (args == NULL ? Py_None : args),
+        (kwargs == NULL ? Py_None : kwargs));
     if (result == NULL) {
         PyErr_PrintEx(0);
         log_error("failed to create stream init event");
@@ -326,7 +359,6 @@ void create_stream_source_event(PyObject *stream, PyObject *args, PyObject *kwar
     Py_XDECREF(result);
 }
 
-
 #ifdef PY2
 /* Apply the rule for the hooked exec statement in Py27 */
 void apply_exec_hook(const char *str) {
@@ -339,10 +371,9 @@ void apply_exec_hook(const char *str) {
     result = PyObject_CallMethod(
         exec_hook_module,
         EXEC_HOOK_NAME,
-        "skO",
-        str,                /* string itself, converted to Python str */
-        (unsigned long)str, /* pointer to string as integer value */
-        get_frame()         /* stack frame object */
+        "sk",
+        str,               /* string itself, converted to Python str */
+        (unsigned long)str /* pointer to string as integer value */
     );
 
     if (result == NULL) {
