@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.wsgi.middleware import WSGIMiddleware
+from contrast.agent.middlewares.app_finder import get_original_app_or_fail
 from contrast.utils.decorators import fail_safely, fail_quietly
 from contrast.extern import structlog as logging
 from contrast.agent.middlewares.route_coverage.bottle_routes import (
     create_bottle_routes,
     build_bottle_route,
 )
+import bottle
 
 logger = logging.getLogger("contrast")
 
@@ -15,8 +17,14 @@ logger = logging.getLogger("contrast")
 class BottleMiddleware(WSGIMiddleware):
     # Since Bottle is WSGI-based, there is no way to retrieve the app name.
     # Use common config to define an app name.
-    def __init__(self, app):
-        super(BottleMiddleware, self).__init__(app, app_name="Bottle Application")
+    def __init__(self, app, orig_bottle_app=None):
+        _app = (
+            orig_bottle_app
+            if orig_bottle_app is not None
+            and isinstance(orig_bottle_app, bottle.Bottle)
+            else get_original_app_or_fail(app, bottle.Bottle)
+        )
+        super(BottleMiddleware, self).__init__(_app, app_name="Bottle Application")
 
     @fail_safely("Unable to get route coverage", return_value={})
     def get_route_coverage(self):
