@@ -1,15 +1,16 @@
 from collections import namedtuple
 import os
 
+from contrast import AGENT_CURR_WORKING_DIR
 import contrast.utils.configuration_utils as utils
 
+from contrast.utils.decorators import cached_property
 from contrast.utils.loggers import DEFAULT_PROGNAME
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
-
-SPLIT_CWD = os.getcwd().split(os.sep)
+SPLIT_CWD = AGENT_CURR_WORKING_DIR.split(os.sep)
 APP_NAME = SPLIT_CWD[len(SPLIT_CWD) - 1]
 ENV_PREFIX = "CONTRAST"
 
@@ -19,6 +20,18 @@ ConfigOption = namedtuple("ConfigOption", ["name", "default_value", "type_cast"]
 DEFAULT_SERVICE_HOST = "127.0.0.1"
 DEFAULT_SERVICE_PORT = 30555
 
+DEFAULT_TEAMSERVER_TYPE = "EOP"
+PUBLIC_SASS_TEAMSERVER_TYPES = {
+    "app.contrastsecurity.com": "SAAS_DEFAULT",
+    "eval.contrastsecurity.com": "SAAS_POV",
+    "ce.contrastsecurity.com": "SAAS_CE",
+}
+PRIVATE_SASS_DOMAIN = "contrastsecurity.com"
+PRIVATE_SASS_TEAMSERVER_TYPE = "SAAS_CUSTOM"
+
+TESTING_TEAMSERVER_NAMES = ["darpa"]
+TESTING_TEAMSERVER_TYPE = "TESTING"
+
 
 class AgentConfig(object):
     def __init__(self):
@@ -117,7 +130,11 @@ class AgentConfig(object):
             self.put(host_key, DEFAULT_SERVICE_HOST)
             self.put(port_key, DEFAULT_SERVICE_PORT)
             msg = "Neither {} nor the pair of {} and {} are set. Falling back to default TCP socket host: {}, port: {}.".format(
-                socket_key, host_key, port_key, self.get(host_key), self.get(port_key),
+                socket_key,
+                host_key,
+                port_key,
+                self.get(host_key),
+                self.get(port_key),
             )
 
         msg_prefix = "Missing a required connection value to the Contrast Service."
@@ -131,6 +148,27 @@ class AgentConfig(object):
     def get_session_metadata(self):
         return self.get("application.session_metadata", "")
 
+    @cached_property
+    def teamserver_type(self):
+        url = self.get("api.url")
+
+        if url is None:
+            return ""
+
+        for name, ts_type in PUBLIC_SASS_TEAMSERVER_TYPES.items():
+            if name in url:
+                return ts_type
+
+        for name in TESTING_TEAMSERVER_NAMES:
+            if name in url:
+                return TESTING_TEAMSERVER_TYPE
+
+        return (
+            PRIVATE_SASS_TEAMSERVER_TYPE
+            if PRIVATE_SASS_DOMAIN in url
+            else DEFAULT_TEAMSERVER_TYPE
+        )
+
 
 class ConfigBuilder(object):
     TOP_LEVEL = ""
@@ -188,10 +226,16 @@ class Agent(ConfigBuilder):
 
         self.default_options = [
             # Some logger default values are handled by the logger
-            ConfigOption(name="logger.level", default_value="", type_cast=str,),
+            ConfigOption(
+                name="logger.level",
+                default_value="",
+                type_cast=str,
+            ),
             ConfigOption(name="logger.path", default_value="", type_cast=str),
             ConfigOption(
-                name="logger.progname", default_value=DEFAULT_PROGNAME, type_cast=str,
+                name="logger.progname",
+                default_value=DEFAULT_PROGNAME,
+                type_cast=str,
             ),
             ConfigOption(
                 name="python.enable_drf_response_analysis",
@@ -203,6 +247,11 @@ class Agent(ConfigBuilder):
                 default_value=True,
                 type_cast=utils.str_to_bool,
             ),
+            ConfigOption(
+                name="python.assess.use_pure_python_hooks",
+                default_value=False,
+                type_cast=utils.str_to_bool,
+            ),
             ConfigOption(
                 name="polling.app_activity_ms", default_value=30000, type_cast=int
             ),
@@ -232,7 +281,9 @@ class Application(ConfigBuilder):
             ConfigOption(name="group", default_value="", type_cast=str),
             ConfigOption(name="metadata", default_value="", type_cast=str),
             ConfigOption(
-                name="name", default_value=os.path.basename(os.getcwd()), type_cast=str
+                name="name",
+                default_value=os.path.basename(AGENT_CURR_WORKING_DIR),
+                type_cast=str,
             ),
             ConfigOption(name="path", default_value="", type_cast=str),
             ConfigOption(name="tags", default_value="", type_cast=str),
@@ -272,6 +323,26 @@ class Assess(ConfigBuilder):
                 default_value="ALL",
                 type_cast=utils.parse_stacktraces_options,
             ),
+            ConfigOption(
+                name="max_context_source_events",
+                default_value=100,
+                type_cast=int,
+            ),
+            ConfigOption(
+                name="max_propagation_events",
+                default_value=250,
+                type_cast=int,
+            ),
+            ConfigOption(
+                name="time_limit_threshold",
+                default_value=300000,  # 5 minutes in ms
+                type_cast=int,
+            ),
+            ConfigOption(
+                name="max_rule_reported",
+                default_value=100,
+                type_cast=int,
+            ),
         ]
 
 
@@ -395,6 +466,11 @@ class Protect(ConfigBuilder):
                 default_value=None,
                 type_cast=utils.protect_mode_to_protobuf,
             ),
+            ConfigOption(
+                name="rules.unsafe-file-upload.mode",
+                default_value=None,
+                type_cast=utils.protect_mode_to_protobuf,
+            ),
             ConfigOption(
                 name="rules.xxe.mode",
                 default_value=None,
