@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Contains dependencies of the agent that we have chosen to vendor
@@ -17,14 +17,5 @@ calculating test coverage since it is technically out of our control. In
 general we should not make changes to the code in this directory other than to
 introduce a different version of a particular package.
 
-Packages included:
-    - backports.functools_lru_cache-1.5
-    - isort-5.6.4 (only the stdlibs subpackage)
-    - ruamel.yaml-0.16.10
-    - WebOb-1.8.6
-    - six-1.14.0
-    - wrapt-1.12.1
-    - pathlib2-2.3.5 (Python 2.7 only)
-    - scandir-1.10.0 (required for pathlib2)
-    - structlog-20.1.0
+A list of included packages can be found under extern-requirements.txt.
 """
