@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern import structlog as logging
 
@@ -9,54 +9,68 @@ logger = logging.getLogger("contrast")
 from . import (
     cs_cstringio,
     cs_io,
+    encodings_patch,
     re_patch,
     threading_patch,
     exec_and_eval,
     lxml_patch,
-    pycryptodome_patch,
-    pyramid_patch,
-    library_reader_import_patches,
+    pathlib_patch,
+    sys_patch,
+    import_patch,
+    cgi_patch,
+    concurrent_futures_thread_patch,
 )
 
 from .databases import (
     mysql_connector_patch,
     pymysql_patch,
     psycopg2_patch,
-    pycassa_patch,
     sqlalchemy_patch,
     sqlite3_patch,
 )
 
-from .frameworks import django_patches, drf_patches
+from .frameworks import (
+    bottle_patches,
+    django_patches,
+    drf_patches,
+    falcon_multipart_patch,
+    pyramid_patch,
+    starlette_patches,
+)
 
 
 COMMON_PATCH_MODULES = (
-    # pycrypto_patch,
-    pycryptodome_patch,
-    # pycryptodomex_patch,
+    pathlib_patch,
     sqlalchemy_patch,
     # our sqlite3_patch also contains the import hook for pysqlite2.dbapi2
     sqlite3_patch,
     mysql_connector_patch,
     pymysql_patch,
     psycopg2_patch,
-    pycassa_patch,
+    concurrent_futures_thread_patch,
 )
 
 
-LIBRARY_READER_PATCHES = (library_reader_import_patches,)
+LIBRARY_READER_PATCHES = (import_patch,)
 
 
 ASSESS_PATCH_MODULES = (
+    threading_patch,
     cs_cstringio,
     cs_io,
+    encodings_patch,
     re_patch,
     exec_and_eval,
     lxml_patch,
     pyramid_patch,
     django_patches,
     drf_patches,
-    threading_patch,
+    bottle_patches,
+    falcon_multipart_patch,
+    sys_patch,
+    import_patch,
+    cgi_patch,
+    starlette_patches,
 )
 
 
