@@ -1,27 +1,28 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Implements a single API for instrumenting all dbapi2-compliant modules
 """
-from contrast.agent.policy import patch_manager
 from contrast.applies.sqli import apply_rule
 from contrast.utils.decorators import fail_safely
-from contrast.utils.patch_utils import patch_cls_or_instance
+from contrast.utils.patch_utils import build_and_apply_patch
 
 
-def _build_patch(database, action):
-    def patched_method(orig_func, patch_policy, *args, **kwargs):
-        return apply_rule(database, action, orig_func, args, kwargs)
+def build_cursor_method_patch(orig_func, patch_policy, database, adapter):
+    def patched_method(*args, **kwargs):
+        return apply_rule(database, adapter, orig_func, args, kwargs)
 
     return patched_method
 
 
 def _instrument_cursor_method(database, cursor, method_name):
-    new_method = _build_patch(database, method_name)
-    patch_cls_or_instance(cursor, method_name, new_method)
-    func = patch_manager.as_func(getattr(cursor, method_name))
-    func.__name__ = method_name
+    build_and_apply_patch(
+        cursor,
+        method_name,
+        build_cursor_method_patch,
+        (database, method_name),
+    )
 
 
 def instrument_cursor(database, cursor):
@@ -73,8 +74,7 @@ def instrument_adapter(database, adapter):
         Safely instrument a Cursor class given an instance of that class
         """
         cursor_class = type(cursor_instance)
-        if not patch_manager.is_patched(cursor_class.execute):
-            instrument_cursor(database, cursor_class)
+        instrument_cursor(database, cursor_class)
 
     @fail_safely("failed to instrument database connection object")
     def safe_instrument_connection(connection_instance):
@@ -82,30 +82,34 @@ def instrument_adapter(database, adapter):
         Safely instrument a Connection class given an instance of that class
         """
         connection_class = type(connection_instance)
-        if not patch_manager.is_patched(connection_class.cursor):
-            patch_cls_or_instance(connection_class, "cursor", cursor_patch)
+        build_and_apply_patch(connection_class, "cursor", build_cursor_patch)
 
-    def cursor_patch(orig_func, _, *args, **kwargs):
-        """
-        Patch for dbapi_adapter.connection().cursor()
+    def build_cursor_patch(orig_func, _):
+        def cursor_patch(*args, **kwargs):
+            """
+            Patch for dbapi_adapter.connection().cursor()
 
-        This patch will ensure that the returned Cursor object's class will have
-        `execute` and `executemany` instrumented.
-        """
-        cursor = orig_func(*args, **kwargs)
-        safe_instrument_cursor(cursor)
-        return cursor
+            This patch will ensure that the returned Cursor object's class will have
+            `execute` and `executemany` instrumented.
+            """
+            cursor = orig_func(*args, **kwargs)
+            safe_instrument_cursor(cursor)
+            return cursor
 
-    def connect_patch(orig_func, _, *args, **kwargs):
-        """
-        Patch for dbapi_adapter.connection()
+        return cursor_patch
 
-        This patch will ensure that the returned Connection object's class will have
-        `cursor_patch` applied to its cursor() method.
-        """
-        connection = orig_func(*args, **kwargs)
-        safe_instrument_connection(connection)
-        return connection
+    def build_connect_patch(orig_func, _):
+        def connect_patch(*args, **kwargs):
+            """
+            Patch for dbapi_adapter.connection()
 
-    if not patch_manager.is_patched(adapter.connect):
-        patch_cls_or_instance(adapter, "connect", connect_patch)
+            This patch will ensure that the returned Connection object's class will have
+            `cursor_patch` applied to its cursor() method.
+            """
+            connection = orig_func(*args, **kwargs)
+            safe_instrument_connection(connection)
+            return connection
+
+        return connect_patch
+
+    build_and_apply_patch(adapter, "connect", build_connect_patch)
