@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Database adapter patch for psycopg2.
@@ -11,8 +11,7 @@ from contrast.extern.wrapt import register_post_import_hook
 
 import contrast
 from contrast.patches.databases import dbapi2
-from contrast.utils import inventory_utils
-from contrast.utils.patch_utils import patch_cls_or_instance
+from contrast.utils import inventory_utils, patch_utils
 
 from contrast.extern import structlog as logging
 
@@ -24,7 +23,7 @@ PSYCOPG2_EXTENSIONS = "psycopg2.extensions"
 CONNECT = "connect"
 
 
-def patch_connect(module):
+def build_connect_patch(orig_func, _):
     """
     Record DB inventory for a Postgres connection.
 
@@ -42,7 +41,7 @@ def patch_connect(module):
     the dsn string only), but this is unlikely and it would only affect inventory.
     """
 
-    def _connect(orig_func, patch_policy=None, *args, **kwargs):
+    def connect(*args, **kwargs):
         connection = orig_func(*args, **kwargs)
         try:
             context = contrast.CS__CONTEXT_TRACKER.current()
@@ -57,7 +56,7 @@ def patch_connect(module):
 
         return connection
 
-    patch_cls_or_instance(module, "connect", _connect)
+    return connect
 
 
 def _get_inventory_params(connection, kwargs):
@@ -85,7 +84,7 @@ def _get_inventory_params(connection, kwargs):
 
 
 def instrument_psycopg2(psycopg2):
-    patch_connect(psycopg2)
+    patch_utils.build_and_apply_patch(psycopg2, "connect", build_connect_patch)
 
 
 def instrument_extensions(psycopg2_extensions):
