@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.wrapt import register_post_import_hook
 
 import contrast
 from contrast.patches.databases import dbapi2
-from contrast.utils import inventory_utils
-from contrast.utils.patch_utils import patch_cls_or_instance
+from contrast.utils import inventory_utils, patch_utils
 
 from contrast.extern import structlog as logging
 
@@ -16,8 +15,8 @@ PYMYSQL = "pymysql"
 VENDOR = "MySQL"
 
 
-def patch_connect(module):
-    def _connect(orig_func, patch_policy=None, *args, **kwargs):
+def build_connect_patch(orig_func, _):
+    def connect(*args, **kwargs):
         """Record DB inventory for MySQL"""
         try:
             context = contrast.CS__CONTEXT_TRACKER.current()
@@ -34,14 +33,14 @@ def patch_connect(module):
 
         return orig_func(*args, **kwargs)
 
-    patch_cls_or_instance(module, "connect", _connect)
+    return connect
 
 
 def instrument_pymysql(pymysql):
     """
     Note: Unlike other sql drivers, pymysql does not have an executescript method.
     """
-    patch_connect(pymysql)
+    patch_utils.build_and_apply_patch(pymysql, "connect", build_connect_patch)
     dbapi2.instrument_cursor(PYMYSQL, pymysql.cursors.Cursor)
 
 
