@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.wrapt import register_post_import_hook
 import sys
 import contrast
 from contrast.agent.policy import patch_manager
 from contrast.patches.databases import dbapi2
-from contrast.utils import inventory_utils
-from contrast.utils.patch_utils import patch_cls_or_instance
+from contrast.utils import inventory_utils, patch_utils
 
 from contrast.extern import structlog as logging
 
@@ -19,8 +18,8 @@ PYSQLITE2_DBAPI2 = "pysqlite2.dbapi2"
 VENDOR = "SQLite3"
 
 
-def patch_connect(module):
-    def _connect(orig_func, patch_policy=None, *args, **kwargs):
+def build_connect_patch(orig_func, _):
+    def connect(*args, **kwargs):
         """Record DB inventory for SQLite3 connection"""
         try:
             context = contrast.CS__CONTEXT_TRACKER.current()
@@ -36,20 +35,20 @@ def patch_connect(module):
 
         return orig_func(*args, **kwargs)
 
-    patch_cls_or_instance(module, "connect", _connect)
+    return connect
 
 
 def instrument_sqlite_dbapi2(sqlite3):
     dbapi2.instrument_cursor(SQLITE3, sqlite3.Cursor)
     dbapi2.instrument_executescript(SQLITE3, sqlite3.Cursor)
-    patch_connect(sqlite3)
+    patch_utils.build_and_apply_patch(sqlite3, "connect", build_connect_patch)
 
 
 def instrument_pysqlite2_dbapi2(pysqlite2):
     """Supports the older pysqlite module in Py2"""
     dbapi2.instrument_cursor(PYSQLITE2_DBAPI2, pysqlite2.Cursor)
     dbapi2.instrument_executescript(PYSQLITE2_DBAPI2, pysqlite2.Cursor)
-    patch_connect(pysqlite2)
+    patch_utils.build_and_apply_patch(pysqlite2, "connect", build_connect_patch)
 
 
 def register_patches():
