@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Instrumentation for eval in PY2 and exec/eval for PY3.
@@ -19,14 +19,14 @@ import contrast
 from contrast.agent import scope
 from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy import trigger_policy
-from contrast.utils.patch_utils import patch_cls_or_instance
+from contrast.utils.patch_utils import build_and_apply_patch
 from contrast.applies.assess.unsafe_code_execution import (
     apply_rule as apply_unsafe_code_exec_rule,
 )
 from contrast.utils.decorators import fail_safely
 
 
-INSTRUMENTED_FRAME_DEPTH = 3
+INSTRUMENTED_FRAME_DEPTH = 1
 
 
 @fail_safely("Error applying rule for exec/eval patch")
@@ -50,8 +50,8 @@ def apply_pt_rule(module, method, result, args, kwargs):
         trigger_policy.apply(trigger_rule, trigger_nodes, result, args, kwargs)
 
 
-def build_exec_eval_patch(rule_applicator):
-    def exec_eval_patch(orig_func, patch_policy, code, globs=None, locs=None):
+def build_exec_eval_patch(orig_func, _, rule_applicator):
+    def exec_eval_patch(code, globs=None, locs=None):
         """
         Run exec/eval call with proper context to adjust for current frame
 
@@ -94,15 +94,22 @@ def build_exec_eval_patch(rule_applicator):
 
 
 def patch_exec_and_eval(builtins_module):
-    exec_eval_patch = build_exec_eval_patch(apply_unsafe_code_exec_rule)
-    patch_cls_or_instance(builtins_module, "eval", exec_eval_patch)
+    build_and_apply_patch(
+        builtins_module, "eval", build_exec_eval_patch, (apply_unsafe_code_exec_rule,)
+    )
 
     if PY2:
-        execfile_patch = build_exec_eval_patch(apply_pt_rule)
-        patch_cls_or_instance(builtins_module, "execfile", execfile_patch)
+        build_and_apply_patch(
+            builtins_module, "execfile", build_exec_eval_patch, (apply_pt_rule,)
+        )
         # exec patch is handled in C extension for Py27
     else:
-        patch_cls_or_instance(builtins_module, "exec", exec_eval_patch)
+        build_and_apply_patch(
+            builtins_module,
+            "exec",
+            build_exec_eval_patch,
+            (apply_unsafe_code_exec_rule,),
+        )
 
 
 def register_patches():
