@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 
@@ -10,7 +10,7 @@ from contrast.agent.assess.policy.analysis import _analyze
 from contrast.agent.policy import patch_manager
 from contrast.agent.policy.loader import Policy
 from contrast.utils.decorators import fail_safely
-from contrast.utils.patch_utils import patch_cls_or_instance
+from contrast.utils.patch_utils import build_and_apply_patch
 
 
 @fail_safely("Failed to apply assess xpath-injection")
@@ -107,16 +107,19 @@ def create_instrumented_xpath(XPath):
     return ContrastXPath
 
 
-def XPathEvaluator(orig_func, patch_policy, *args, **kwargs):
-    """
-    Instrumented version of XPathEvaluator factory
-    """
-    evaluator = orig_func(*args, **kwargs)
-    return ContrastXPathEvaluatorProxy(evaluator)
+def build_XPathEvaluator_patch(orig_func, _):
+    def XPathEvaluator(*args, **kwargs):
+        """
+        Instrumented version of XPathEvaluator factory
+        """
+        evaluator = orig_func(*args, **kwargs)
+        return ContrastXPathEvaluatorProxy(evaluator)
+
+    return XPathEvaluator
 
 
 def patch_etree(etree_module):
-    patch_cls_or_instance(etree_module, "XPathEvaluator", XPathEvaluator)
+    build_and_apply_patch(etree_module, "XPathEvaluator", build_XPathEvaluator_patch)
 
     new_xpath = create_instrumented_xpath(etree_module.XPath)
     patch_manager.patch(etree_module, "XPath", new_xpath)
