@@ -1,10 +1,14 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from io import IOBase
+try:
+    from django.http.response import HttpResponseBase
+
+    django_response_types = (HttpResponseBase,)
+except ImportError:  # pragma: no cover
+    django_response_types = ()
 
 from contrast.extern import six
-
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
@@ -33,13 +37,6 @@ def is_iterable(value):
     return not isinstance(value, string_types)
 
 
-def is_filelike(value):
-    if six.PY2:
-        return isinstance(value, file)
-
-    return isinstance(value, IOBase)
-
-
 def len_or_zero(value):
     try:
         return len(value)
@@ -49,16 +46,21 @@ def len_or_zero(value):
 
 def safe_iterator(it):
     if isinstance(it, (list_iterator, dict_iterator)):
-        logger.debug("WARNING: skipping iteration of non-seekable iterator: %s", it)
+        logger.debug(
+            "WARNING: skipping iteration of non-seekable iterator: %s", type(it)
+        )
         return
 
-    if isinstance(it, (str, list, dict)):
+    if isinstance(it, (str, list, dict)) or (
+        isinstance(it, django_response_types)
+        and not safe_getattr(it, "streaming", True)
+    ):
         for x in it:
             yield x
         return
 
     if not (hasattr(it, "tell") and hasattr(it, "seek")):
-        logger.debug("WARNING: skipping iteration of non-seekable object: %s", it)
+        logger.debug("WARNING: skipping iteration of non-seekable object: %s", type(it))
         return
 
     try:
@@ -67,7 +69,7 @@ def safe_iterator(it):
         for x in it:
             yield x
     except Exception:
-        logger.debug("safe_iterator failed to iterate over %s", it)
+        logger.debug("safe_iterator failed to iterate over %s", type(it))
     finally:
         it.seek(orig_pos)
 
