@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.api.dtm_pb2 import ArchitectureComponent
 
@@ -36,6 +36,8 @@ def _build_architecture_component(obj):
 
     arch_comp.type = "db"
 
-    arch_comp.url = obj["database"] if "database" in obj else "default"
+    arch_comp.url = (
+        obj["database"] if "database" in obj else (arch_comp.vendor or "default")
+    )
 
     return arch_comp
