@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 import hashlib
-import json
 
 import pkg_resources
 from contrast.agent import scope
@@ -111,34 +110,46 @@ def get_top_level_directories_namespace_pkg(dist, namespace):
 
 def get_top_level_directories(dist):
     """
+    Parse the top_level.txt or RECORD file for a dist to get the dist's
+    top level directories.
 
-    @param dist: Distribution object used to check to see what
-    metadata files exist for us to parse
-    @type dist: pkg_resources.DistInfoDistribution
-    @return: list of top level importable modules/packages for the dist
-    @rtype: list
+    :param dist: instance of pkg_resources.DistInfoDistribution
+    :return: list of strs representing names of top level dist directories
     """
-    # some packages have multiple top level directories, so check for all of them
     top_level_dirs = []
 
-    # file storing directory names for top level directories of package
     if dist.has_metadata(TOP_LEVEL_TXT):
         top_level_dirs = list(dist.get_metadata_lines(TOP_LEVEL_TXT))
     elif dist.has_metadata(RECORD):
-        # TODO: PYT-927 Code needs to properly parse TLDs from RECORD file
-        metadata_lines = [d.split(",")[0] for d in dist.get_metadata_lines(RECORD)]
-
-        top_level_dirs = [
-            x
-            for x in metadata_lines
-            if "/" in x and x.split(os.sep)[1] == "__init__.py"
-        ]
+        top_level_dirs = _parse_record_lines(dist.get_metadata_lines(RECORD))
     else:
         logger.debug("Cannot find top level dirs for %s", dist)
 
     return top_level_dirs
 
 
+def _parse_record_lines(record_data_generator):
+    """
+    For lines in a RECORD file, parse out the name(s) of the top level directories.
+
+    :param record_data_generator: generator containing lines in RECORD file
+    :return: list of strs representing names of top level dist directories
+    """
+    top_level_dirs = []
+    for full_name in record_data_generator:
+        name = full_name.split(",")[0]
+        if os.sep in name and name.split(os.sep)[1] == "__init__.py":
+            top_level_dirs.append(name.split(os.sep)[0])
+        elif name.endswith(SO_SUFFIX):
+            # Handle special case where an .so file is a top level importable module.
+            # This library is loaded by importing the name of the file excluding
+            # the platform specific name convention of the file
+            # i.e remove .cpython-PY_VERSION-platform.so from module.cpython-PY_VERSION-platform.so
+            top_level_dirs.append(name.split(".")[0])
+
+    return top_level_dirs
+
+
 def get_file_from_module(module):
     if hasattr(module, "__file__") and module.__file__:
         return os.path.realpath(module.__file__)
@@ -147,16 +158,19 @@ def get_file_from_module(module):
 
 
 def get_url_from_dist(dist):
+    """
+    Gets the library url from either PKG-INFO or METADATA files
+    :param dist: the distribution package where data is being parsed
+    :return: the url of the package or "" if one wasn't discovered
+    """
+    home_page = "Home-page: "
     url = ""
-    # If the data has a .json format
-    if dist.PKG_INFO == "METADATA":
-        url = _get_url_from_metadata(dist)
 
-    # If the data is in PKG-INFO form
-    elif dist.PKG_INFO == "PKG-INFO":
-        url = _get_url_from_pkg_info(dist)
-
-    # If the metadata is not in either form
+    metadata = list(dist.get_metadata_lines(dist.PKG_INFO))
+    for line in metadata:
+        if line.startswith(home_page):
+            url = line.split(home_page)[1]
+            break
     else:
         logger.debug("Cannot find url for %s", dist)
 
@@ -175,58 +189,6 @@ def get_data(dist):
     return version, manifest, str(url)
 
 
-EXTENTIONS = "extensions"
-HOME = "Home"
-PROJECT_URLS = "project_urls"
-PYTHON_DETAILS = "python.details"
-
-
-def _get_url_from_metadata(dist):
-    """
-    Gets the library url if PKG_INFO is packaged in a json
-    :param dist: the distribution package who's data is being parsed
-    :return: the url of the package
-    """
-
-    try:
-        metadata = json.loads(dist.get_metadata("metadata.json"))
-
-        if PROJECT_URLS in metadata[EXTENTIONS][PYTHON_DETAILS]:
-            return metadata[EXTENTIONS][PYTHON_DETAILS][PROJECT_URLS][HOME]
-    except Exception:
-        pass
-
-    try:
-        metadata = json.loads(dist.get_metadata("pydist.json"))
-        if PROJECT_URLS in metadata:
-            return metadata[PROJECT_URLS][HOME]
-    except Exception:
-        pass
-
-    return ""
-
-
-HOME_PAGE = "Home-page: "
-
-
-def _get_url_from_pkg_info(dist):
-    """
-    Gets the library url if PKG_INFO is packaged in a text file
-    :param dist: the distribution package who's data is being parsed
-    :return: the url of the package
-    """
-
-    # Split metadata so it can be searched
-    metadata = list(dist.get_metadata_lines(dist.PKG_INFO))
-
-    # Search metadata for homepage
-    for line in metadata:
-        if line.startswith(HOME_PAGE):
-            return line.split(HOME_PAGE)[1]
-
-    return ""
-
-
 def get_hash(name, version):
     """
     DO NOT ALTER OR REMOVE
