@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import copy
+from inspect import isclass
 
 
 def safe_copy(value):
@@ -15,3 +16,7 @@ def safe_copy(value):
         return copy.copy(value)
     except:
         return value
+
+
+def get_name(obj):
+    return "{0.__module__}.{0.__name__}".format(obj) if isclass(obj) else obj.__name__
