@@ -1,141 +1,93 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import OrderedDict
 import inspect
 import sys
 
 from contrast.utils.decorators import fail_safely
-from contrast.extern.six import iteritems, PY2
+from contrast.extern.six import ensure_str, iteritems, PY2
+from contrast.extern import wrapt
 
 from contrast.agent.policy import patch_manager
 from contrast.utils.ignored_modules import (
     ALL_MODULES_TO_IGNORE,
     MODULES_TO_IGNORE_PREFIXES,
 )
-from contrast.utils.object_share import ObjectShare
+from contrast.utils.object_utils import get_name
 
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
 
+def add_watermark(func):
+    """Adds a "secret" attribute to patched function for debugging purposes"""
+    try:
+        func.__contrast__ = True
+    except Exception:
+        pass
+    return func
+
+
 def module_is_ignored(module_name):
     return module_name in ALL_MODULES_TO_IGNORE or module_name.startswith(
         MODULES_TO_IGNORE_PREFIXES
     )
 
 
-def call_patch(
-    new_function, original_function, patch_policy, *orig_func_args, **orig_func_kwargs
-):
-    return new_function(
-        original_function, patch_policy, *orig_func_args, **orig_func_kwargs
-    )
-
-
-def curry(new_function, original_func, patch_policy):
-    def _curried(*orig_func_args, **orig_func_kwargs):
-        return call_patch(
-            new_function,
-            original_func,
-            patch_policy,
-            *orig_func_args,
-            **orig_func_kwargs
-        )
-
-    return _curried
-
-
-def patch_cls_or_instance(
-    patch_target,
-    method_name,
-    new_function=None,
-    patch_policy=None,
-    static_method=False,
-    class_method=False,
-    assess_patch=False,
+def build_and_apply_patch(
+    owner, attr_name, patch_builder, builder_args=None, owner_name=None
 ):
     """
-    Apply a patch to given module, class, or object instance
+    Builds new patch using given builder and applies it to specified patch location
 
-    :param patch_target: The class, module, or object instance to be patched
-    :param method_name: The name of the method (or function) that is being replaced
-    :param patch_policy: patch policy location instance
-    :param new_function: The function that will replace the original function
-    :param static_method: Indicates whether method being replaced is a staticmethod
-    :param class_method: Indicates whether method being replaced is a classmethod
+    :param owner: Module or class where patch will be applied
+    :param loc_name: Fully specified name of module or class where patch will apply
+    :param attr_name: Name of the method that is being patched/replaced
+    :param patch_builder: Callback function used to build new patch
+    :param builder_args: A tuple of positional args to be passed to `patch_builder`
+
+    The `patch_builder` function must take at least two arguments:
+        1. A pointer to the original function
+        2. The patch policy associated with this patch (may be `None`)
+    The `patch_builder` may accept additional positional arguments that are passed to
+    this function as a tuple via `builder_args`.
+
+    The `patch_builder` function must return a function that matches the argument
+    signature of the original function. The returned function must call the original
+    function and return the result.
+
+    Not all patches will have policy. Some patch locations are used solely to apply
+    proxies or do library analysis, and so no policy exists for those locations.
+    Callers can indicate this by passing "" or None for `loc_name`, in which case no
+    patch policy will be retrieved.
     """
-    cs_method_name = (
-        ObjectShare.CONTRAST_ASSESS_METHOD_START + method_name
-        if assess_patch
-        else method_name
-    )
+    original_func = getattr(owner, attr_name)
 
-    original_func = getattr(patch_target, cs_method_name)
+    # We don't expect this to ever really happen except possibly in test code;
+    # particularly in framework tests. Eventually we may just want to reverse patches
+    # between test cases rather than have some awkward logic here.
     if patch_manager.is_patched(original_func):
-        # TODO: PYT-692 investigate unexpected patching
-        logger.debug(
-            "WARNING! Method %s is not getting patched - already patched", method_name
-        )
         return
 
-    curried = curry(new_function, original_func, patch_policy)
+    from contrast.agent.policy.loader import Policy
 
-    if static_method:
-        curried_function = staticmethod(curried)
-    elif class_method:
-        curried_function = classmethod(curried)
-    elif callable(new_function) or hasattr(new_function, "__call__"):
-        if isinstance(original_func, property):
-            curried_function = property(
-                fget=curry(new_function, method_name, patch_policy),
-                fset=original_func.fset,
-                fdel=original_func.fdel,
-            )
-        else:
-            curried_function = curried
-    else:
-        logger.debug(
-            "WARNING! Method %s is not getting patched - unrecognized object type: %s",
-            method_name,
-            type(original_func),
-        )
-        return
+    loc_name = owner_name if owner_name is not None else get_name(owner)
 
-    patch_manager.patch(patch_target, method_name, curried_function)
+    patch_policy = (
+        Policy().policy_by_name.get("{}.{}".format(loc_name, attr_name))
+        if loc_name
+        else None
+    )
 
+    patch = patch_builder(original_func, patch_policy, *(builder_args or ()))
 
-def patch_property(
-    class_to_patch, property_name, new_property_method, patch_policy=None
-):
-    """
-    Patch properties which require both fget and fset to be set.
-    This currently supports the case for the DjangoORM. Column name attributes
-    for the model that defines database operations operate as properties.
-    While in patch_cls_or_instance we handle properties, here we handle this special
-    case that fails if fset is not defined.
+    patch_manager.patch(owner, attr_name, patch)
 
-    Note the definition of fset is the most basic definition of a setter, which is
-    sufficient to make the getter/setter implementation of the property patching work.
-    """
-    original_prop = getattr(class_to_patch, property_name)
-    if patch_manager.is_patched(original_prop):
-        return
-
-    fget = curry(new_property_method, property_name, patch_policy)
-
-    def fset(cls_instance, value):
-        # while good instinct would lead us to use setattr here instead of __dict__,
-        # doing so does not work because we are in fact within a setter!
-        cls_instance.__dict__[property_name] = value
-
-    new_property = property(fget=fget, fset=fset)
-    patch_manager.patch(class_to_patch, property_name, new_property)
-
-
-CONTRAST_MODULE = "contrast."
-INTELLIJ_MODULE = "pydevd"
+    func = add_watermark(patch_manager.as_func(getattr(owner, attr_name)))
+    if hasattr(func, "__name__") and not isinstance(func, wrapt.FunctionWrapper):
+        func.__name__ = ensure_str(attr_name)
 
 
 def get_loaded_modules(use_for_patching=False):
@@ -269,11 +221,4 @@ def repatch_imported_modules():
     patches in those modules.
     """
     for _, module in get_loaded_modules(use_for_patching=True).items():
-
-        if patch_manager.is_visited(module):
-            continue
-
         repatch_module(module)
-
-        # Prevent us from re-repatching =D
-        patch_manager.mark_visited(module)
