@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import platform
 import psutil
+import time
 from os import path
 
 from contrast.extern import structlog as logging
@@ -22,6 +23,13 @@ def make_sure_path_exists(log_path):
     pathlib.Path(directory).mkdir(parents=True, exist_ok=True)
 
 
+def sleep(seconds):
+    """
+    Wrapper around time.sleep that makes testing less complicated
+    """
+    time.sleep(seconds)
+
+
 class ServiceUtil(object):
     SERVICE_EXE_NAME = "contrast-service"
     BASE_SERVICE_DIRECTORY = "service_executables"
