@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern import six
 
@@ -8,14 +8,14 @@ from contrast.extern import structlog as logging
 logger = logging.getLogger("contrast")
 
 
-def truncate(value, default=""):
+def truncate(value, default="", length=256):
     """
-    Truncate to 256 characters
+    Truncate to `length` characters
     """
     if value is None:
         return default
 
-    return value[:256]
+    return value[:length]
 
 
 def truncated_signature(value):
