@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2020 Contrast Security, Inc.
+# Copyright © 2021 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.webob import Request, Response
 
@@ -8,7 +8,7 @@ from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.middlewares.base_middleware import BaseMiddleware
 from contrast.agent.middlewares.environ_tracker import track_environ_sources
 from contrast.agent.request_context import RequestContext
-from contrast.utils.decorators import cached_property, fail_safely
+from contrast.utils.decorators import cached_property, fail_safely, log_time_cm
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
@@ -17,6 +17,7 @@ from contrast.utils.exceptions.contrast_service_exception import (
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
+DEFAULT_WSGI_NAME = "wsgi_app"
 
 
 class WSGIMiddleware(BaseMiddleware):
@@ -24,21 +25,23 @@ class WSGIMiddleware(BaseMiddleware):
     Contrast middleware; PEP-333(3) WSGI-compliant
     """
 
-    def __init__(self, wsgi_app, app_name="WSGI Application"):
-        self.app_name = app_name
+    def __init__(self, wsgi_app, app_name=None):
+        if app_name:
+            self.app_name = app_name
+        elif hasattr(wsgi_app, "__name__"):
+            self.app_name = wsgi_app.__name__
+        else:
+            self.app_name = DEFAULT_WSGI_NAME
 
         super(WSGIMiddleware, self).__init__()
 
         self.wsgi_app = wsgi_app
 
     def __call__(self, environ, start_response):
+        self.orig_path_info = environ.get("PATH_INFO")
+
         if self.is_agent_enabled():
-
             context = RequestContext(environ)
-
-            if self.settings.is_assess_enabled():
-                track_environ_sources("wsgi", context, environ)
-
             with contrast.CS__CONTEXT_TRACKER.lifespan(context):
                 return self.call_with_agent(context, environ, start_response)
 
@@ -47,16 +50,15 @@ class WSGIMiddleware(BaseMiddleware):
     def call_with_agent(self, context, environ, start_response):
         self.log_start_request_analysis(environ.get("PATH_INFO"))
 
-        context.timer.set_start("total")
+        track_environ_sources("wsgi", context, environ)
 
         try:
             self.prefilter(context)
 
-            logger.debug("Start app code and get response")
-            # this returns a webob response class, which already
-            # implements BaseResponseWrapper's requirements
-            response = Request(environ).get_response(self.wsgi_app)
-            logger.debug("Finished app code and get response")
+            with log_time_cm("app code and get response"):
+                # this returns a webob response class, which already
+                # implements BaseResponseWrapper's requirements
+                response = Request(environ).get_response(self.wsgi_app)
 
             context.extract_response_to_context(response)
 
@@ -64,7 +66,6 @@ class WSGIMiddleware(BaseMiddleware):
 
             self.check_for_blocked(context)
 
-            context.timer.set_end("total")
             return response(environ, start_response)
 
         except ContrastServiceException as e:
@@ -74,11 +75,33 @@ class WSGIMiddleware(BaseMiddleware):
             response = self.handle_exception(e)
             return response(environ, start_response)
         finally:
+            self.swap_environ_path(environ)
             self.handle_ensure(context, context.request)
             self.log_end_request_analysis(context.request.path)
             if self.settings.is_assess_enabled():
                 contrast.STRING_TRACKER.ageoff()
 
+    def swap_environ_path(self, environ):
+        """
+        See PYT-1742.
+
+        Special behavior required for bottle+django to account for an unfortunate
+        encoding behavior.
+
+        In bottle, it occurs here:
+        bottle.py:
+        def _handle(self, environ):
+            ...
+            environ['PATH_INFO'] = path.encode('latin1').decode('utf8')
+            ...
+
+        This casing occurs after the application code is called, and will result in a
+        `UnicodeEncodeError` when the agent attempts to access request.path.
+        As a workaround, we store the original PATH_INFO - before bottle changed it
+        during calling app code - and use it for agent purposes.
+        """
+        environ["PATH_INFO"] = self.orig_path_info
+
     def generate_security_exception_response(self):
         return Response(self.OVERRIDE_MESSAGE, SecurityException.STATUS)
 
@@ -92,8 +115,8 @@ class WSGIMiddleware(BaseMiddleware):
     def get_route_coverage(self):
         """
         Unlike frameworks, WSGI is a spec, so it does not have a way to register routes.
-        As such, there is no way to discover routes. Instead, routes will be added as they
-        are visited via check for new routes.
+        As such, there is no way to discover routes. Instead, routes will be added as
+        they are visited via check for new routes.
 
         :return: empty dict
         """
@@ -107,9 +130,7 @@ class WSGIMiddleware(BaseMiddleware):
         The rule itself is implemented in the base middleware but we need to
         provide a WSGI-specific trigger node for reporting purposes.
         """
-        method_name = (
-            self.wsgi_app.__name__ if hasattr(self.wsgi_app, "__name__") else "wsgi_app"
-        )
+        method_name = self.app_name
 
         module, class_name, args, instance_method = self._process_trigger_handler(
             self.wsgi_app
